summaryrefslogtreecommitdiff
path: root/libavformat
diff options
context:
space:
mode:
authorVittorio Giovara <vittorio.giovara@gmail.com>2016-04-27 13:45:23 -0400
committerDiego Biurrun <diego@biurrun.de>2016-05-04 18:16:21 +0200
commit41ed7ab45fc693f7d7fc35664c0233f4c32d69bb (patch)
tree146a086cf7c1881d55f9261b58138983e13af21c /libavformat
parent5c31eaa9998b2185e0aa04d11adff128498dc14a (diff)
cosmetics: Fix spelling mistakes
Signed-off-by: Diego Biurrun <diego@biurrun.de>
Diffstat (limited to 'libavformat')
-rw-r--r--libavformat/4xm.c2
-rw-r--r--libavformat/aea.c2
-rw-r--r--libavformat/amr.c4
-rw-r--r--libavformat/asf.h2
-rw-r--r--libavformat/asfdec.c6
-rw-r--r--libavformat/asfenc.c4
-rw-r--r--libavformat/avc.c2
-rw-r--r--libavformat/avformat.h2
-rw-r--r--libavformat/avidec.c2
-rw-r--r--libavformat/avio.h8
-rw-r--r--libavformat/avisynth.c2
-rw-r--r--libavformat/avlanguage.h2
-rw-r--r--libavformat/bink.c2
-rw-r--r--libavformat/bmv.c2
-rw-r--r--libavformat/dump.c2
-rw-r--r--libavformat/dv.c16
-rw-r--r--libavformat/dvenc.c4
-rw-r--r--libavformat/electronicarts.c2
-rw-r--r--libavformat/flic.c2
-rw-r--r--libavformat/flvdec.c4
-rw-r--r--libavformat/gxfenc.c2
-rw-r--r--libavformat/hevc.c2
-rw-r--r--libavformat/http.h2
-rw-r--r--libavformat/httpauth.h2
-rw-r--r--libavformat/id3v2enc.c2
-rw-r--r--libavformat/idcin.c4
-rw-r--r--libavformat/idroqdec.c2
-rw-r--r--libavformat/iff.c2
-rw-r--r--libavformat/internal.h2
-rw-r--r--libavformat/ipmovie.c2
-rw-r--r--libavformat/isom.c92
-rw-r--r--libavformat/matroska.c2
-rw-r--r--libavformat/matroska.h2
-rw-r--r--libavformat/mms.c2
-rw-r--r--libavformat/mmsh.c2
-rw-r--r--libavformat/mmst.c4
-rw-r--r--libavformat/mov.c6
-rw-r--r--libavformat/movenc-test.c10
-rw-r--r--libavformat/movenc.c6
-rw-r--r--libavformat/mpeg.c4
-rw-r--r--libavformat/mpeg.h2
-rw-r--r--libavformat/mpegenc.c6
-rw-r--r--libavformat/mpegts.c10
-rw-r--r--libavformat/mpegts.h2
-rw-r--r--libavformat/mpegtsenc.c10
-rw-r--r--libavformat/mxf.c10
-rw-r--r--libavformat/mxfdec.c12
-rw-r--r--libavformat/mxfenc.c12
-rw-r--r--libavformat/nsvdec.c8
-rw-r--r--libavformat/oggparsedirac.c4
-rw-r--r--libavformat/psxstr.c2
-rw-r--r--libavformat/rdt.c2
-rw-r--r--libavformat/rl2.c2
-rw-r--r--libavformat/rmenc.c8
-rw-r--r--libavformat/rtmphttp.c2
-rw-r--r--libavformat/rtmpproto.c10
-rw-r--r--libavformat/rtpdec.c2
-rw-r--r--libavformat/rtpdec_h263_rfc2190.c2
-rw-r--r--libavformat/rtpdec_h264.c10
-rw-r--r--libavformat/rtpdec_mpeg4.c4
-rw-r--r--libavformat/rtpdec_qt.c2
-rw-r--r--libavformat/rtpdec_vp8.c2
-rw-r--r--libavformat/rtpenc.c4
-rw-r--r--libavformat/rtpenc.h2
-rw-r--r--libavformat/rtpenc_h261.c4
-rw-r--r--libavformat/rtpenc_h263_rfc2190.c6
-rw-r--r--libavformat/rtpenc_jpeg.c2
-rw-r--r--libavformat/rtpenc_xiph.c2
-rw-r--r--libavformat/sdp.c2
-rw-r--r--libavformat/segafilm.c2
-rw-r--r--libavformat/sierravmd.c2
-rw-r--r--libavformat/spdif.h4
-rw-r--r--libavformat/spdifenc.c8
-rw-r--r--libavformat/url.h2
-rw-r--r--libavformat/wc3movie.c2
-rw-r--r--libavformat/westwood_aud.c2
-rw-r--r--libavformat/westwood_vqa.c4
-rw-r--r--libavformat/wtv.c4
78 files changed, 200 insertions, 200 deletions
diff --git a/libavformat/4xm.c b/libavformat/4xm.c
index 6889ca4c37..1597b3b569 100644
--- a/libavformat/4xm.c
+++ b/libavformat/4xm.c
@@ -1,6 +1,6 @@
/*
* 4X Technologies .4xm File Demuxer (no muxer)
- * Copyright (c) 2003 The ffmpeg Project
+ * Copyright (c) 2003 The FFmpeg project
*
* This file is part of Libav.
*
diff --git a/libavformat/aea.c b/libavformat/aea.c
index a20bf7ca67..fc914f08fb 100644
--- a/libavformat/aea.c
+++ b/libavformat/aea.c
@@ -32,7 +32,7 @@ static int aea_read_probe(AVProbeData *p)
if (p->buf_size <= 2048+212)
return 0;
- /* Magic is '00 08 00 00' in Little Endian*/
+ /* Magic is '00 08 00 00' in little-endian*/
if (AV_RL32(p->buf)==0x800) {
int bsm_s, bsm_e, inb_s, inb_e, ch;
ch = p->buf[264];
diff --git a/libavformat/amr.c b/libavformat/amr.c
index 580e9339a3..cdba27d430 100644
--- a/libavformat/amr.c
+++ b/libavformat/amr.c
@@ -1,6 +1,6 @@
/*
* amr file format
- * Copyright (c) 2001 ffmpeg project
+ * Copyright (c) 2001 FFmpeg project
*
* This file is part of Libav.
*
@@ -115,7 +115,7 @@ static int amr_read_packet(AVFormatContext *s, AVPacket *pkt)
return AVERROR(EIO);
}
- // FIXME this is wrong, this should rather be in a AVParset
+ // FIXME this is wrong, this should rather be in an AVParser
toc = avio_r8(s->pb);
mode = (toc >> 3) & 0x0F;
diff --git a/libavformat/asf.h b/libavformat/asf.h
index 7ac28dbb30..6130e7aaa6 100644
--- a/libavformat/asf.h
+++ b/libavformat/asf.h
@@ -40,7 +40,7 @@ typedef struct ASFMainHeader {
* invalid if broadcasting (could be ignored) */
uint32_t preroll; /**< timestamp of the first packet, in milliseconds
* if nonzero - subtract from time */
- uint32_t ignore; ///< preroll is 64bit - but let's just ignore it
+ uint32_t ignore; ///< preroll is 64 bits - but let's just ignore it
uint32_t flags; /**< 0x01 - broadcast
* 0x02 - seekable
* rest is reserved should be 0 */
diff --git a/libavformat/asfdec.c b/libavformat/asfdec.c
index f232374831..7d71789029 100644
--- a/libavformat/asfdec.c
+++ b/libavformat/asfdec.c
@@ -121,8 +121,8 @@ typedef struct ASFContext {
int stream_index; // from packet header, for the subpayload case
- // packet parameteres
- uint64_t sub_header_offset; // offset of subplayload header
+ // packet parameters
+ uint64_t sub_header_offset; // offset of subpayload header
int64_t sub_dts;
uint8_t dts_delta; // for subpayloads
uint32_t packet_size_internal; // packet size stored inside ASFPacket, can be 0
@@ -1175,7 +1175,7 @@ static int asf_read_multiple_payload(AVFormatContext *s, AVPacket *pkt,
int ret;
int skip = 0;
- // if replicated lenght is 1, subpayloads are present
+ // if replicated length is 1, subpayloads are present
if (asf->rep_data_len == 1) {
asf->sub_left = 1;
asf->state = READ_MULTI_SUB;
diff --git a/libavformat/asfenc.c b/libavformat/asfenc.c
index c61335b776..dc1dd73364 100644
--- a/libavformat/asfenc.c
+++ b/libavformat/asfenc.c
@@ -209,7 +209,7 @@ typedef struct ASFContext {
uint32_t seqno;
int is_streamed;
ASFStream streams[128]; ///< it's max number and it's not that big
- /* non streamed additonnal info */
+ /* non-streamed additional info */
uint64_t nb_packets; ///< how many packets are there in the file, invalid if broadcasting
uint64_t duration; ///< in ms
/* packet filling */
@@ -446,7 +446,7 @@ static int asf_write_header1(AVFormatContext *s, int64_t file_size,
avio_wl16(pb, 0);
end_header(pb, hpos);
- /* title and other infos */
+ /* title and other info */
if (has_title) {
int len;
uint8_t *buf;
diff --git a/libavformat/avc.c b/libavformat/avc.c
index e639ed5593..5bfbad89da 100644
--- a/libavformat/avc.c
+++ b/libavformat/avc.c
@@ -106,7 +106,7 @@ int ff_avc_parse_nal_units_buf(const uint8_t *buf_in, uint8_t **buf, int *size)
int ff_isom_write_avcc(AVIOContext *pb, const uint8_t *data, int len)
{
if (len > 6) {
- /* check for h264 start code */
+ /* check for H.264 start code */
if (AV_RB32(data) == 0x00000001 ||
AV_RB24(data) == 0x000001) {
uint8_t *buf=NULL, *end, *start;
diff --git a/libavformat/avformat.h b/libavformat/avformat.h
index 43e2bbd16b..7d026b66d5 100644
--- a/libavformat/avformat.h
+++ b/libavformat/avformat.h
@@ -1931,7 +1931,7 @@ void av_url_split(char *proto, int proto_size,
* @param ic the context to analyze
* @param index the index to print, if you have multiple inputs or outputs
* @param url the URL to print, such as source or destination file
- * @param is_output whether the context is input or ouput
+ * @param is_output whether the context is input or output
*/
void av_dump_format(AVFormatContext *ic,
int index,
diff --git a/libavformat/avidec.c b/libavformat/avidec.c
index f5705e5436..3666b573e0 100644
--- a/libavformat/avidec.c
+++ b/libavformat/avidec.c
@@ -548,7 +548,7 @@ static int avi_read_header(AVFormatContext *s)
st->start_time = 0;
avio_rl32(pb); /* buffer size */
avio_rl32(pb); /* quality */
- ast->sample_size = avio_rl32(pb); /* sample ssize */
+ ast->sample_size = avio_rl32(pb); /* sample size */
ast->cum_len *= FFMAX(1, ast->sample_size);
av_log(s, AV_LOG_TRACE, "%"PRIu32" %"PRIu32" %d\n",
ast->rate, ast->scale, ast->sample_size);
diff --git a/libavformat/avio.h b/libavformat/avio.h
index 889fdcf1e7..13a8b196c1 100644
--- a/libavformat/avio.h
+++ b/libavformat/avio.h
@@ -195,16 +195,16 @@ int avio_put_str16le(AVIOContext *s, const char *str);
int avio_put_str16be(AVIOContext *s, const char *str);
/**
- * Passing this as the "whence" parameter to a seek function causes it to
+ * ORing this as the "whence" parameter to a seek function causes it to
* return the filesize without seeking anywhere. Supporting this is optional.
* If it is not supported then the seek function will return <0.
*/
#define AVSEEK_SIZE 0x10000
/**
- * Oring this flag as into the "whence" parameter to a seek function causes it to
- * seek by any means (like reopening and linear reading) or other normally unreasonble
- * means that can be extreemly slow.
+ * Passing this flag as the "whence" parameter to a seek function causes it to
+ * seek by any means (like reopening and linear reading) or other normally unreasonable
+ * means that can be extremely slow.
* This may be ignored by the seek code.
*/
#define AVSEEK_FORCE 0x20000
diff --git a/libavformat/avisynth.c b/libavformat/avisynth.c
index b00f9bc42e..fe71a427a6 100644
--- a/libavformat/avisynth.c
+++ b/libavformat/avisynth.c
@@ -1,6 +1,6 @@
/*
* AviSynth/AvxSynth support
- * Copyright (c) 2012 AvxSynth Team.
+ * Copyright (c) 2012 AvxSynth Team
*
* This file is part of Libav.
*
diff --git a/libavformat/avlanguage.h b/libavformat/avlanguage.h
index 2ec3e2d372..128fb1c999 100644
--- a/libavformat/avlanguage.h
+++ b/libavformat/avlanguage.h
@@ -26,7 +26,7 @@
*/
enum AVLangCodespace {
AV_LANG_ISO639_2_BIBL, /** 3-char bibliographic language codes as per ISO-IEC 639-2 */
- AV_LANG_ISO639_2_TERM, /** 3-char terminologic language codes as per ISO-IEC 639-2 */
+ AV_LANG_ISO639_2_TERM, /** 3-char terminological language codes as per ISO-IEC 639-2 */
AV_LANG_ISO639_1 /** 2-char code of language as per ISO/IEC 639-1 */
};
diff --git a/libavformat/bink.c b/libavformat/bink.c
index 807e51b3d9..377db98971 100644
--- a/libavformat/bink.c
+++ b/libavformat/bink.c
@@ -239,7 +239,7 @@ static int read_packet(AVFormatContext *s, AVPacket *pkt)
pkt->pts = bink->audio_pts[bink->current_track - 1];
/* Each audio packet reports the number of decompressed samples
- (in bytes). We use this value to calcuate the audio PTS */
+ (in bytes). We use this value to calculate the audio PTS */
if (pkt->size >= 4)
bink->audio_pts[bink->current_track -1] +=
AV_RL32(pkt->data) / (2 * s->streams[bink->current_track]->codecpar->channels);
diff --git a/libavformat/bmv.c b/libavformat/bmv.c
index cfb4439edc..9bc8dda871 100644
--- a/libavformat/bmv.c
+++ b/libavformat/bmv.c
@@ -1,6 +1,6 @@
/*
* Discworld II BMV demuxer
- * Copyright (c) 2011 Konstantin Shishkov.
+ * Copyright (c) 2011 Konstantin Shishkov
*
* This file is part of Libav.
*
diff --git a/libavformat/dump.c b/libavformat/dump.c
index d7dee9d570..a66e48ca11 100644
--- a/libavformat/dump.c
+++ b/libavformat/dump.c
@@ -357,7 +357,7 @@ static void dump_sidedata(void *ctx, AVStream *st, const char *indent)
dump_paramchange(ctx, &sd);
break;
case AV_PKT_DATA_H263_MB_INFO:
- av_log(ctx, AV_LOG_INFO, "h263 macroblock info");
+ av_log(ctx, AV_LOG_INFO, "H.263 macroblock info");
break;
case AV_PKT_DATA_REPLAYGAIN:
av_log(ctx, AV_LOG_INFO, "replaygain: ");
diff --git a/libavformat/dv.c b/libavformat/dv.c
index f7df279bdc..d4e51807d7 100644
--- a/libavformat/dv.c
+++ b/libavformat/dv.c
@@ -102,11 +102,11 @@ static const int dv_audio_frequency[3] = {
/*
* There's a couple of assumptions being made here:
- * 1. By default we silence erroneous (0x8000/16bit 0x800/12bit) audio samples.
+ * 1. By default we silence erroneous (0x8000/16-bit 0x800/12-bit) audio samples.
* We can pass them upwards when libavcodec will be ready to deal with them.
* 2. We don't do software emphasis.
- * 3. Audio is always returned as 16bit linear samples: 12bit nonlinear samples
- * are converted into 16bit linear ones.
+ * 3. Audio is always returned as 16-bit linear samples: 12-bit nonlinear samples
+ * are converted into 16-bit linear ones.
*/
static int dv_extract_audio(uint8_t *frame, uint8_t **ppcm,
const AVDVProfile *sys)
@@ -122,7 +122,7 @@ static int dv_extract_audio(uint8_t *frame, uint8_t **ppcm,
smpls = as_pack[1] & 0x3f; /* samples in this frame - min. samples */
freq = as_pack[4] >> 3 & 0x07; /* 0 - 48kHz, 1 - 44,1kHz, 2 - 32kHz */
- quant = as_pack[4] & 0x07; /* 0 - 16bit linear, 1 - 12bit nonlinear */
+ quant = as_pack[4] & 0x07; /* 0 - 16-bit linear, 1 - 12-bit nonlinear */
if (quant > 1)
return -1; /* unsupported quantization */
@@ -148,7 +148,7 @@ static int dv_extract_audio(uint8_t *frame, uint8_t **ppcm,
for (i = 0; i < sys->difseg_size; i++) {
frame += 6 * 80; /* skip DIF segment header */
if (quant == 1 && i == half_ch) {
- /* next stereo channel (12bit mode only) */
+ /* next stereo channel (12-bit mode only) */
pcm = ppcm[ipcm++];
if (!pcm)
break;
@@ -157,7 +157,7 @@ static int dv_extract_audio(uint8_t *frame, uint8_t **ppcm,
/* for each AV sequence */
for (j = 0; j < 9; j++) {
for (d = 8; d < 80; d += 2) {
- if (quant == 0) { /* 16bit quantization */
+ if (quant == 0) { /* 16-bit quantization */
of = sys->audio_shuffle[i][j] +
(d - 8) / 2 * sys->audio_stride;
if (of * 2 >= size)
@@ -170,7 +170,7 @@ static int dv_extract_audio(uint8_t *frame, uint8_t **ppcm,
if (pcm[of * 2 + 1] == 0x80 && pcm[of * 2] == 0x00)
pcm[of * 2 + 1] = 0;
- } else { /* 12bit quantization */
+ } else { /* 12-bit quantization */
lc = ((uint16_t)frame[d] << 4) |
((uint16_t)frame[d + 2] >> 4);
rc = ((uint16_t)frame[d + 1] << 4) |
@@ -219,7 +219,7 @@ static int dv_extract_audio_info(DVDemuxContext *c, uint8_t *frame)
smpls = as_pack[1] & 0x3f; /* samples in this frame - min. samples */
freq = as_pack[4] >> 3 & 0x07; /* 0 - 48kHz, 1 - 44,1kHz, 2 - 32kHz */
stype = as_pack[3] & 0x1f; /* 0 - 2CH, 2 - 4CH, 3 - 8CH */
- quant = as_pack[4] & 0x07; /* 0 - 16bit linear, 1 - 12bit nonlinear */
+ quant = as_pack[4] & 0x07; /* 0 - 16-bit linear, 1 - 12-bit nonlinear */
if (freq >= FF_ARRAY_ELEMS(dv_audio_frequency)) {
av_log(c->fctx, AV_LOG_ERROR,
diff --git a/libavformat/dvenc.c b/libavformat/dvenc.c
index 094ddc90a9..cf795347ad 100644
--- a/libavformat/dvenc.c
+++ b/libavformat/dvenc.c
@@ -38,7 +38,7 @@
#include "libavutil/fifo.h"
#include "libavutil/mathematics.h"
-#define MAX_AUDIO_FRAME_SIZE 192000 // 1 second of 48khz 32bit audio
+#define MAX_AUDIO_FRAME_SIZE 192000 // 1 second of 48khz 32-bit audio
struct DVMuxContext {
const AVDVProfile* sys; /* current DV profile, e.g.: 525/60, 625/50 */
@@ -124,7 +124,7 @@ static int dv_write_pack(enum dv_pack_type pack_id, DVMuxContext *c, uint8_t* bu
buf[4] = (1 << 7) | /* emphasis: 1 -- off */
(0 << 6) | /* emphasis time constant: 0 -- reserved */
(0 << 3) | /* frequency: 0 -- 48kHz, 1 -- 44,1kHz, 2 -- 32kHz */
- 0; /* quantization: 0 -- 16bit linear, 1 -- 12bit nonlinear */
+ 0; /* quantization: 0 -- 16-bit linear, 1 -- 12-bit nonlinear */
va_end(ap);
break;
case dv_audio_control:
diff --git a/libavformat/electronicarts.c b/libavformat/electronicarts.c
index 07d1efceac..2df27e4a00 100644
--- a/libavformat/electronicarts.c
+++ b/libavformat/electronicarts.c
@@ -1,5 +1,5 @@
/* Electronic Arts Multimedia File Demuxer
- * Copyright (c) 2004 The ffmpeg Project
+ * Copyright (c) 2004 The FFmpeg project
* Copyright (c) 2006-2008 Peter Ross
*
* This file is part of Libav.
diff --git a/libavformat/flic.c b/libavformat/flic.c
index cb88b67521..85e4790f87 100644
--- a/libavformat/flic.c
+++ b/libavformat/flic.c
@@ -1,6 +1,6 @@
/*
* FLI/FLC Animation File Demuxer
- * Copyright (c) 2003 The ffmpeg Project
+ * Copyright (c) 2003 The FFmpeg project
*
* This file is part of Libav.
*
diff --git a/libavformat/flvdec.c b/libavformat/flvdec.c
index a9bead5fda..0d9a113edb 100644
--- a/libavformat/flvdec.c
+++ b/libavformat/flvdec.c
@@ -4,8 +4,8 @@
*
* This demuxer will generate a 1 byte extradata for VP6F content.
* It is composed of:
- * - upper 4bits: difference between encoded width and visible width
- * - lower 4bits: difference between encoded height and visible height
+ * - upper 4 bits: difference between encoded width and visible width
+ * - lower 4 bits: difference between encoded height and visible height
*
* This file is part of Libav.
*
diff --git a/libavformat/gxfenc.c b/libavformat/gxfenc.c
index 22ae315e2d..60f88fdabd 100644
--- a/libavformat/gxfenc.c
+++ b/libavformat/gxfenc.c
@@ -42,7 +42,7 @@ typedef struct GXFStreamContext {
int pframes;
int bframes;
int p_per_gop;
- int b_per_i_or_p; ///< number of B frames per I frame or P frame
+ int b_per_i_or_p; ///< number of B-frames per I-frame or P-frame
int first_gop_closed;
unsigned order; ///< interleaving order
} GXFStreamContext;
diff --git a/libavformat/hevc.c b/libavformat/hevc.c
index e59d6a8886..c835f2243e 100644
--- a/libavformat/hevc.c
+++ b/libavformat/hevc.c
@@ -799,7 +799,7 @@ static void hvcc_init(HEVCDecoderConfigurationRecord *hvcc)
/*
* Initialize this field with an invalid value which can be used to detect
- * whether we didn't see any VUI (in wich case it should be reset to zero).
+ * whether we didn't see any VUI (in which case it should be reset to zero).
*/
hvcc->min_spatial_segmentation_idc = MAX_SPATIAL_SEGMENTATION + 1;
}
diff --git a/libavformat/http.h b/libavformat/http.h
index 3d301a715f..b8fe33b962 100644
--- a/libavformat/http.h
+++ b/libavformat/http.h
@@ -40,7 +40,7 @@ void ff_http_init_auth_state(URLContext *dest, const URLContext *src);
/**
* Send a new HTTP request, reusing the old connection.
*
- * @param h pointer to the ressource
+ * @param h pointer to the resource
* @param uri uri used to perform the request
* @return a negative value if an error condition occurred, 0
* otherwise
diff --git a/libavformat/httpauth.h b/libavformat/httpauth.h
index 99bf43ffdc..9bfbc520ef 100644
--- a/libavformat/httpauth.h
+++ b/libavformat/httpauth.h
@@ -62,7 +62,7 @@ typedef struct HTTPAuthState {
*/
char realm[200];
/**
- * The parameters specifiec to digest authentication.
+ * The parameters specific to digest authentication.
*/
DigestParams digest_params;
/**
diff --git a/libavformat/id3v2enc.c b/libavformat/id3v2enc.c
index 827431aee3..3f9bd4ecd7 100644
--- a/libavformat/id3v2enc.c
+++ b/libavformat/id3v2enc.c
@@ -83,7 +83,7 @@ static int id3v2_put_ttag(ID3v2EncContext *id3, AVIOContext *avioc, const char *
len = avio_close_dyn_buf(dyn_buf, &pb);
avio_wb32(avioc, tag);
- /* ID3v2.3 frame size is not synchsafe */
+ /* ID3v2.3 frame size is not sync-safe */
if (id3->version == 3)
avio_wb32(avioc, len);
else
diff --git a/libavformat/idcin.c b/libavformat/idcin.c
index b7b85c99cf..86e9f41e0b 100644
--- a/libavformat/idcin.c
+++ b/libavformat/idcin.c
@@ -1,6 +1,6 @@
/*
* id Quake II CIN File Demuxer
- * Copyright (c) 2003 The ffmpeg Project
+ * Copyright (c) 2003 The FFmpeg project
*
* This file is part of Libav.
*
@@ -33,7 +33,7 @@
* types. However, a CIN file does start with 5 32-bit numbers that
* specify audio and video parameters. This demuxer gets around the lack
* of file signature by performing sanity checks on those parameters.
- * Probabalistically, this is a reasonable solution since the number of
+ * Probabilistically, this is a reasonable solution since the number of
* valid combinations of the 5 parameters is a very small subset of the
* total 160-bit number space.
*
diff --git a/libavformat/idroqdec.c b/libavformat/idroqdec.c
index 62d81f6658..a40894686d 100644
--- a/libavformat/idroqdec.c
+++ b/libavformat/idroqdec.c
@@ -1,6 +1,6 @@
/*
* id RoQ (.roq) File Demuxer
- * Copyright (c) 2003 The ffmpeg Project
+ * Copyright (c) 2003 The FFmpeg project
*
* This file is part of Libav.
*
diff --git a/libavformat/iff.c b/libavformat/iff.c
index d81a1ff561..52c7e97280 100644
--- a/libavformat/iff.c
+++ b/libavformat/iff.c
@@ -194,7 +194,7 @@ static int iff_read_header(AVFormatContext *s)
compression = avio_r8(pb);
}
if (data_size >= 16) {
- avio_skip(pb, 3); // paddding, transparent
+ avio_skip(pb, 3); // padding, transparent
st->sample_aspect_ratio.num = avio_r8(pb);
st->sample_aspect_ratio.den = avio_r8(pb);
}
diff --git a/libavformat/internal.h b/libavformat/internal.h
index c87d0ebde6..4760ba89ff 100644
--- a/libavformat/internal.h
+++ b/libavformat/internal.h
@@ -437,7 +437,7 @@ static inline int ff_rename(const char *oldpath, const char *newpath)
/**
* A wrapper around AVFormatContext.io_close that should be used
- * intead of calling the pointer directly.
+ * instead of calling the pointer directly.
*/
void ff_format_io_close(AVFormatContext *s, AVIOContext **pb);
diff --git a/libavformat/ipmovie.c b/libavformat/ipmovie.c
index 2ef5ca0739..b719fed2b9 100644
--- a/libavformat/ipmovie.c
+++ b/libavformat/ipmovie.c
@@ -1,6 +1,6 @@
/*
* Interplay MVE File Demuxer
- * Copyright (c) 2003 The ffmpeg Project
+ * Copyright (c) 2003 The FFmpeg project
*
* This file is part of Libav.
*
diff --git a/libavformat/matroska.c b/libavformat/matroska.c
index a57b9637ce..c25c962363 100644
--- a/libavformat/matroska.c
+++ b/libavformat/matroska.c
@@ -1,6 +1,6 @@
/*
* Matroska common data
- * Copyright (c) 2003-2004 The ffmpeg Project
+ * Copyright (c) 2003-2004 The FFmpeg project
*
* This file is part of Libav.
*
diff --git a/libavformat/matroska.h b/libavformat/matroska.h
index 40402bcdb8..a13de18ef1 100644
--- a/libavformat/matroska.h
+++ b/libavformat/matroska.h
@@ -1,6 +1,6 @@
/*
* Matroska constants
- * Copyright (c) 2003-2004 The ffmpeg Project
+ * Copyright (c) 2003-2004 The FFmpeg project
*
* This file is part of Libav.
*
diff --git a/libavformat/mms.c b/libavformat/mms.c
index 92de81d768..fc967c1892 100644
--- a/libavformat/mms.c
+++ b/libavformat/mms.c
@@ -97,7 +97,7 @@ int ff_mms_asf_header_parser(MMSContext *mms)
flags = AV_RL16(p + sizeof(ff_asf_guid)*3 + 24);
stream_id = flags & 0x7F;
//The second condition is for checking CS_PKT_STREAM_ID_REQUEST packet size,
- //we can calcuate the packet size by stream_num.
+ //we can calculate the packet size by stream_num.
//Please see function send_stream_selection_request().
if (mms->stream_num < MMS_MAX_STREAMS &&
46 + mms->stream_num * 6 < sizeof(mms->out_buffer)) {
diff --git a/libavformat/mmsh.c b/libavformat/mmsh.c
index 4c1ed05b24..4029b86371 100644
--- a/libavformat/mmsh.c
+++ b/libavformat/mmsh.c
@@ -41,7 +41,7 @@
// see Ref 2.2.1.8
#define USERAGENT "User-Agent: NSPlayer/4.1.0.3856\r\n"
// see Ref 2.2.1.4.33
-// the guid value can be changed to any valid value.
+// the GUID value can be changed to any valid value.
#define CLIENTGUID "Pragma: xClientGUID={c77e7400-738a-11d2-9add-0020af0a3278}\r\n"
// see Ref 2.2.3 for packet type define:
diff --git a/libavformat/mmst.c b/libavformat/mmst.c
index 1489076ad3..f3a51577ca 100644
--- a/libavformat/mmst.c
+++ b/libavformat/mmst.c
@@ -419,7 +419,7 @@ static int send_startup_packet(MMSTContext *mmst)
char data_string[256];
MMSContext *mms = &mmst->mms;
// SubscriberName is defined in MS specification linked below.
- // The guid value can be any valid value.
+ // The GUID value can be any valid value.
// http://download.microsoft.com/
// download/9/5/E/95EF66AF-9026-4BB0-A41D-A4F81802D92C/%5BMS-WMSP%5D.pdf
snprintf(data_string, sizeof(data_string),
@@ -515,7 +515,7 @@ static int mms_open(URLContext *h, const char *uri, int flags)
sizeof(mmst->path), uri);
if(port<0)
- port = 1755; // defaut mms protocol port
+ port = 1755; // default MMS protocol port
// establish tcp connection.
ff_url_join(tcpname, sizeof(tcpname), "tcp", NULL, mmst->host, port, NULL);
diff --git a/libavformat/mov.c b/libavformat/mov.c
index ac6ff5d565..376820cd27 100644
--- a/libavformat/mov.c
+++ b/libavformat/mov.c
@@ -1141,7 +1141,7 @@ static int mov_read_fiel(MOVContext *c, AVIOContext *pb, MOVAtom atom)
return 0;
}
-/* FIXME modify qdm2/svq3/h264 decoders to take full atom as extradata */
+/* FIXME modify QDM2/SVQ3/H.264 decoders to take full atom as extradata */
static int mov_read_extradata(MOVContext *c, AVIOContext *pb, MOVAtom atom)
{
AVStream *st;
@@ -1373,7 +1373,7 @@ static int mov_codec_id(AVStream *st, uint32_t format)
if (st->codecpar->codec_type != AVMEDIA_TYPE_VIDEO && id > 0) {
st->codecpar->codec_type = AVMEDIA_TYPE_AUDIO;
} else if (st->codecpar->codec_type != AVMEDIA_TYPE_AUDIO &&
- /* skip old asf mpeg4 tag */
+ /* skip old ASF MPEG-4 tag */
format && format != MKTAG('m','p','4','s')) {
id = ff_codec_get_id(ff_codec_movvideo_tags, format);
if (id <= 0)
@@ -1427,7 +1427,7 @@ static void mov_parse_stsd_video(MOVContext *c, AVIOContext *pb,
/* codec_tag YV12 triggers an UV swap in rawdec.c */
if (!memcmp(codec_name, "Planar Y'CbCr 8-bit 4:2:0", 25))
st->codecpar->codec_tag = MKTAG('I', '4', '2', '0');
- /* Flash Media Server uses tag H263 with Sorenson Spark */
+ /* Flash Media Server uses tag H.263 with Sorenson Spark */
if (st->codecpar->codec_tag == MKTAG('H','2','6','3') &&
!memcmp(codec_name, "Sorenson H263", 13))
st->codecpar->codec_id = AV_CODEC_ID_FLV1;
diff --git a/libavformat/movenc-test.c b/libavformat/movenc-test.c
index 2847522f50..e7b67e1e7a 100644
--- a/libavformat/movenc-test.c
+++ b/libavformat/movenc-test.c
@@ -349,7 +349,7 @@ int main(int argc, char **argv)
finish();
close_out();
- // Write a similar file, but with b-frames and audio preroll, handled
+ // Write a similar file, but with B-frames and audio preroll, handled
// via an edit list.
init_out("non-empty-moov-elst");
av_dict_set(&opts, "movflags", "frag_keyframe", 0);
@@ -359,7 +359,7 @@ int main(int argc, char **argv)
finish();
close_out();
- // Use b-frames but no audio-preroll, but without an edit list.
+ // Use B-frames but no audio-preroll, but without an edit list.
// Due to avoid_negative_ts == AVFMT_AVOID_NEG_TS_MAKE_ZERO, the dts
// of the first audio packet is > 0, but it is set to zero since edit
// lists aren't used, increasing the duration of the first packet instead.
@@ -372,7 +372,7 @@ int main(int argc, char **argv)
close_out();
format = "ismv";
- // Write an ISMV, with b-frames and audio preroll.
+ // Write an ISMV, with B-frames and audio preroll.
init_out("ismv");
av_dict_set(&opts, "movflags", "frag_keyframe", 0);
init(1, 1);
@@ -554,7 +554,7 @@ int main(int argc, char **argv)
finish();
- // Test discontinously written fragments with b-frames (where the
+ // Test discontinuously written fragments with B-frames (where the
// assumption of starting at pts=0 works) but not with audio preroll
// (which can't be guessed).
av_dict_set(&opts, "movflags", "frag_custom+delay_moov+dash", 0);
@@ -588,7 +588,7 @@ int main(int argc, char **argv)
finish();
- // Test discontinously written fragments with b-frames and audio preroll,
+ // Test discontinuously written fragments with B-frames and audio preroll,
// properly signaled.
av_dict_set(&opts, "movflags", "frag_custom+delay_moov+dash", 0);
init(1, 1);
diff --git a/libavformat/movenc.c b/libavformat/movenc.c
index 84a57c180e..f7bbb2f8ed 100644
--- a/libavformat/movenc.c
+++ b/libavformat/movenc.c
@@ -1657,7 +1657,7 @@ static int mov_write_edts_tag(AVIOContext *pb, MOVMuxContext *mov,
/* In the positive delay case, the delay includes the cts
* offset, and the second edit list entry below trims out
* the same amount from the actual content. This makes sure
- * that the offsetted last sample is included in the edit
+ * that the offset last sample is included in the edit
* list duration as well. */
if (version == 1) {
avio_wb64(pb, delay);
@@ -3433,8 +3433,8 @@ int ff_mov_write_packet(AVFormatContext *s, AVPacket *pkt)
}
if (par->codec_id == AV_CODEC_ID_H264 && trk->vos_len > 0 && *(uint8_t *)trk->vos_data != 1) {
- /* from x264 or from bytestream h264 */
- /* nal reformating needed */
+ /* from x264 or from bytestream H.264 */
+ /* NAL reformatting needed */
if (trk->hint_track >= 0 && trk->hint_track < mov->nb_streams) {
ff_avc_parse_nal_units_buf(pkt->data, &reformatted_data,
&size);
diff --git a/libavformat/mpeg.c b/libavformat/mpeg.c
index 39374b69b6..f63e79f673 100644
--- a/libavformat/mpeg.c
+++ b/libavformat/mpeg.c
@@ -1,5 +1,5 @@
/*
- * MPEG1/2 demuxer
+ * MPEG-1/2 demuxer
* Copyright (c) 2000, 2001, 2002 Fabrice Bellard
*
* This file is part of Libav.
@@ -287,7 +287,7 @@ redo:
goto error_redo;
c = avio_r8(s->pb);
len--;
- /* XXX: for mpeg1, should test only bit 7 */
+ /* XXX: for MPEG-1, should test only bit 7 */
if (c != 0xff)
break;
}
diff --git a/libavformat/mpeg.h b/libavformat/mpeg.h
index d0b36ee153..7f7f830c28 100644
--- a/libavformat/mpeg.h
+++ b/libavformat/mpeg.h
@@ -1,5 +1,5 @@
/*
- * MPEG1/2 muxer and demuxer common defines
+ * MPEG-1/2 muxer and demuxer common defines
* Copyright (c) 2000, 2001, 2002 Fabrice Bellard
*
* This file is part of Libav.
diff --git a/libavformat/mpegenc.c b/libavformat/mpegenc.c
index 5178746010..1507e0ee30 100644
--- a/libavformat/mpegenc.c
+++ b/libavformat/mpegenc.c
@@ -1,5 +1,5 @@
/*
- * MPEG1/2 muxer
+ * MPEG-1/2 muxer
* Copyright (c) 2000, 2001, 2002 Fabrice Bellard
*
* This file is part of Libav.
@@ -153,7 +153,7 @@ static int put_system_header(AVFormatContext *ctx, uint8_t *buf,
put_bits(&pb, 1, 1);
} else {
put_bits(&pb, 1, 0); /* variable bitrate */
- put_bits(&pb, 1, 0); /* non constrainted bit stream */
+ put_bits(&pb, 1, 0); /* nonconstrained bitstream */
}
if (s->is_vcd || s->is_dvd) {
@@ -1148,7 +1148,7 @@ static int mpeg_mux_end(AVFormatContext *ctx)
break;
}
- /* End header according to MPEG1 systems standard. We do not write
+ /* End header according to MPEG-1 systems standard. We do not write
* it as it is usually not needed by decoders and because it
* complicates MPEG stream concatenation. */
// avio_wb32(ctx->pb, ISO_11172_END_CODE);
diff --git a/libavformat/mpegts.h b/libavformat/mpegts.h
index 7dbbf8dfb0..9f374c623e 100644
--- a/libavformat/mpegts.h
+++ b/libavformat/mpegts.h
@@ -1,5 +1,5 @@
/*
- * MPEG2 transport stream defines
+ * MPEG-2 transport stream defines
* Copyright (c) 2003 Fabrice Bellard
*
* This file is part of Libav.
diff --git a/libavformat/mpegtsenc.c b/libavformat/mpegtsenc.c
index ffbea97633..eca348a007 100644
--- a/libavformat/mpegtsenc.c
+++ b/libavformat/mpegtsenc.c
@@ -1,5 +1,5 @@
/*
- * MPEG2 transport stream (aka DVB) muxer
+ * MPEG-2 transport stream (aka DVB) muxer
* Copyright (c) 2003 Fabrice Bellard
*
* This file is part of Libav.
@@ -48,7 +48,7 @@ typedef struct MpegTSSection {
} MpegTSSection;
typedef struct MpegTSService {
- MpegTSSection pmt; /* MPEG2 pmt table context */
+ MpegTSSection pmt; /* MPEG-2 PMT table context */
int sid; /* service ID */
char *name;
char *provider_name;
@@ -59,8 +59,8 @@ typedef struct MpegTSService {
typedef struct MpegTSWrite {
const AVClass *av_class;
- MpegTSSection pat; /* MPEG2 pat table */
- MpegTSSection sdt; /* MPEG2 sdt table context */
+ MpegTSSection pat; /* MPEG-2 PAT table */
+ MpegTSSection sdt; /* MPEG-2 SDT table context */
MpegTSService **services;
int sdt_packet_count;
int sdt_packet_period;
@@ -726,7 +726,7 @@ fail:
return ret;
}
-/* send SDT, PAT and PMT tables regulary */
+/* send SDT, PAT and PMT tables regularly */
static void retransmit_si_info(AVFormatContext *s)
{
MpegTSWrite *ts = s->priv_data;
diff --git a/libavformat/mxf.c b/libavformat/mxf.c
index 19ee35f3af..0b7e9823b1 100644
--- a/libavformat/mxf.c
+++ b/libavformat/mxf.c
@@ -39,17 +39,17 @@ const MXFCodecUL ff_mxf_codec_uls[] = {
{ { 0x06,0x0E,0x2B,0x34,0x04,0x01,0x01,0x03,0x04,0x01,0x02,0x02,0x01,0x04,0x02,0x00 }, 14, AV_CODEC_ID_MPEG2VIDEO }, /* 422P@HL I-Frame */
{ { 0x06,0x0E,0x2B,0x34,0x04,0x01,0x01,0x03,0x04,0x01,0x02,0x02,0x01,0x20,0x02,0x03 }, 14, AV_CODEC_ID_MPEG4 }, /* XDCAM proxy_pal030926.mxf */
{ { 0x06,0x0E,0x2B,0x34,0x04,0x01,0x01,0x01,0x04,0x01,0x02,0x02,0x02,0x01,0x02,0x00 }, 13, AV_CODEC_ID_DVVIDEO }, /* DV25 IEC PAL */
- { { 0x06,0x0E,0x2B,0x34,0x04,0x01,0x01,0x07,0x04,0x01,0x02,0x02,0x03,0x01,0x01,0x00 }, 14, AV_CODEC_ID_JPEG2000 }, /* JPEG2000 Codestream */
- { { 0x06,0x0E,0x2B,0x34,0x04,0x01,0x01,0x01,0x04,0x01,0x02,0x01,0x7F,0x00,0x00,0x00 }, 13, AV_CODEC_ID_RAWVIDEO }, /* Uncompressed */
- { { 0x06,0x0E,0x2B,0x34,0x04,0x01,0x01,0x0A,0x04,0x01,0x02,0x01,0x01,0x02,0x01,0x00 }, 15, AV_CODEC_ID_RAWVIDEO }, /* Uncompressed 422 8-bit */
+ { { 0x06,0x0E,0x2B,0x34,0x04,0x01,0x01,0x07,0x04,0x01,0x02,0x02,0x03,0x01,0x01,0x00 }, 14, AV_CODEC_ID_JPEG2000 }, /* JPEG 2000 code stream */
+ { { 0x06,0x0E,0x2B,0x34,0x04,0x01,0x01,0x01,0x04,0x01,0x02,0x01,0x7F,0x00,0x00,0x00 }, 13, AV_CODEC_ID_RAWVIDEO }, /* uncompressed */
+ { { 0x06,0x0E,0x2B,0x34,0x04,0x01,0x01,0x0A,0x04,0x01,0x02,0x01,0x01,0x02,0x01,0x00 }, 15, AV_CODEC_ID_RAWVIDEO }, /* uncompressed 422 8-bit */
{ { 0x06,0x0E,0x2B,0x34,0x04,0x01,0x01,0x01,0x04,0x01,0x02,0x02,0x71,0x00,0x00,0x00 }, 13, AV_CODEC_ID_DNXHD }, /* SMPTE VC-3/DNxHD */
{ { 0x06,0x0E,0x2B,0x34,0x04,0x01,0x01,0x01,0x04,0x01,0x02,0x02,0x03,0x02,0x00,0x00 }, 14, AV_CODEC_ID_DNXHD }, /* SMPTE VC-3/DNxHD */
{ { 0x06,0x0E,0x2B,0x34,0x04,0x01,0x01,0x0A,0x04,0x01,0x02,0x02,0x01,0x32,0x00,0x00 }, 14, AV_CODEC_ID_H264 }, /* H.264/MPEG-4 AVC Intra */
{ { 0x06,0x0E,0x2B,0x34,0x04,0x01,0x01,0x0A,0x04,0x01,0x02,0x02,0x01,0x31,0x11,0x01 }, 14, AV_CODEC_ID_H264 }, /* H.264/MPEG-4 AVC SPS/PPS in-band */
{ { 0x06,0x0E,0x2B,0x34,0x04,0x01,0x01,0x0A,0x04,0x01,0x02,0x01,0x01,0x02,0x02,0x00 }, 15, AV_CODEC_ID_V210 }, /* V210 */
/* SoundEssenceCompression */
- { { 0x06,0x0e,0x2b,0x34,0x04,0x01,0x01,0x03,0x04,0x02,0x02,0x02,0x03,0x03,0x01,0x00 }, 14, AV_CODEC_ID_AAC }, /* MPEG2 AAC ADTS (legacy) */
- { { 0x06,0x0E,0x2B,0x34,0x04,0x01,0x01,0x01,0x04,0x02,0x02,0x01,0x00,0x00,0x00,0x00 }, 13, AV_CODEC_ID_PCM_S16LE }, /* Uncompressed */
+ { { 0x06,0x0e,0x2b,0x34,0x04,0x01,0x01,0x03,0x04,0x02,0x02,0x02,0x03,0x03,0x01,0x00 }, 14, AV_CODEC_ID_AAC }, /* MPEG-2 AAC ADTS (legacy) */
+ { { 0x06,0x0E,0x2B,0x34,0x04,0x01,0x01,0x01,0x04,0x02,0x02,0x01,0x00,0x00,0x00,0x00 }, 13, AV_CODEC_ID_PCM_S16LE }, /* uncompressed */
{ { 0x06,0x0E,0x2B,0x34,0x04,0x01,0x01,0x01,0x04,0x02,0x02,0x01,0x7F,0x00,0x00,0x00 }, 13, AV_CODEC_ID_PCM_S16LE },
{ { 0x06,0x0E,0x2B,0x34,0x04,0x01,0x01,0x07,0x04,0x02,0x02,0x01,0x7E,0x00,0x00,0x00 }, 13, AV_CODEC_ID_PCM_S16BE }, /* From Omneon MXF file */
{ { 0x06,0x0E,0x2B,0x34,0x04,0x01,0x01,0x04,0x04,0x02,0x02,0x02,0x03,0x01,0x01,0x00 }, 15, AV_CODEC_ID_PCM_ALAW }, /* XDCAM Proxy C0023S01.mxf */
diff --git a/libavformat/mxfdec.c b/libavformat/mxfdec.c
index c09e4f6dba..ef82f0c6d1 100644
--- a/libavformat/mxfdec.c
+++ b/libavformat/mxfdec.c
@@ -499,7 +499,7 @@ static int mxf_read_partition_pack(void *arg, AVIOContext *pb, int tag, int size
partition->previous_partition);
}
- /* some files don'thave FooterPartition set in every partition */
+ /* some files don't have FooterPartition set in every partition */
if (footer_partition) {
if (mxf->footer_partition && mxf->footer_partition != footer_partition) {
av_log(mxf->fc, AV_LOG_ERROR,
@@ -947,22 +947,22 @@ static void *mxf_resolve_strong_ref(MXFContext *mxf, UID *strong_ref, enum MXFMe
static const MXFCodecUL mxf_picture_essence_container_uls[] = {
// video essence container uls
- { { 0x06,0x0e,0x2b,0x34,0x04,0x01,0x01,0x02,0x0d,0x01,0x03,0x01,0x02,0x04,0x60,0x01 }, 14, AV_CODEC_ID_MPEG2VIDEO }, /* MPEG-ES Frame wrapped */
+ { { 0x06,0x0e,0x2b,0x34,0x04,0x01,0x01,0x02,0x0d,0x01,0x03,0x01,0x02,0x04,0x60,0x01 }, 14, AV_CODEC_ID_MPEG2VIDEO }, /* MPEG-ES frame-wrapped */
{ { 0x06,0x0e,0x2b,0x34,0x04,0x01,0x01,0x01,0x0d,0x01,0x03,0x01,0x02,0x02,0x41,0x01 }, 14, AV_CODEC_ID_DVVIDEO }, /* DV 625 25mbps */
- { { 0x06,0x0e,0x2b,0x34,0x04,0x01,0x01,0x01,0x0d,0x01,0x03,0x01,0x02,0x05,0x00,0x00 }, 14, AV_CODEC_ID_RAWVIDEO }, /* Uncompressed Picture */
+ { { 0x06,0x0e,0x2b,0x34,0x04,0x01,0x01,0x01,0x0d,0x01,0x03,0x01,0x02,0x05,0x00,0x00 }, 14, AV_CODEC_ID_RAWVIDEO }, /* uncompressed picture */
{ { 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00 }, 0, AV_CODEC_ID_NONE },
};
/* EC ULs for intra-only formats */
static const MXFCodecUL mxf_intra_only_essence_container_uls[] = {
- { { 0x06,0x0e,0x2b,0x34,0x04,0x01,0x01,0x01,0x0d,0x01,0x03,0x01,0x02,0x01,0x00,0x00 }, 14, AV_CODEC_ID_MPEG2VIDEO }, /* MXF-GC SMPTE D-10 Mappings */
+ { { 0x06,0x0e,0x2b,0x34,0x04,0x01,0x01,0x01,0x0d,0x01,0x03,0x01,0x02,0x01,0x00,0x00 }, 14, AV_CODEC_ID_MPEG2VIDEO }, /* MXF-GC SMPTE D-10 mappings */
{ { 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00 }, 0, AV_CODEC_ID_NONE },
};
/* intra-only PictureEssenceCoding ULs, where no corresponding EC UL exists */
static const MXFCodecUL mxf_intra_only_picture_essence_coding_uls[] = {
{ { 0x06,0x0e,0x2b,0x34,0x04,0x01,0x01,0x0A,0x04,0x01,0x02,0x02,0x01,0x32,0x00,0x00 }, 14, AV_CODEC_ID_H264 }, /* H.264/MPEG-4 AVC Intra Profiles */
- { { 0x06,0x0e,0x2b,0x34,0x04,0x01,0x01,0x07,0x04,0x01,0x02,0x02,0x03,0x01,0x01,0x00 }, 14, AV_CODEC_ID_JPEG2000 }, /* JPEG2000 Codestream */
+ { { 0x06,0x0e,0x2b,0x34,0x04,0x01,0x01,0x07,0x04,0x01,0x02,0x02,0x03,0x01,0x01,0x00 }, 14, AV_CODEC_ID_JPEG2000 }, /* JPEG 2000 code stream */
{ { 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00 }, 0, AV_CODEC_ID_NONE },
};
@@ -972,7 +972,7 @@ static const MXFCodecUL mxf_sound_essence_container_uls[] = {
{ { 0x06,0x0e,0x2b,0x34,0x04,0x01,0x01,0x02,0x0d,0x01,0x03,0x01,0x02,0x04,0x40,0x01 }, 14, AV_CODEC_ID_MP2 }, /* MPEG-ES Frame wrapped, 0x40 ??? stream id */
{ { 0x06,0x0e,0x2b,0x34,0x04,0x01,0x01,0x01,0x0d,0x01,0x03,0x01,0x02,0x01,0x01,0x01 }, 14, AV_CODEC_ID_PCM_S16LE }, /* D-10 Mapping 50Mbps PAL Extended Template */
{ { 0x06,0x0e,0x2b,0x34,0x01,0x01,0x01,0xff,0x4b,0x46,0x41,0x41,0x00,0x0d,0x4d,0x4F }, 14, AV_CODEC_ID_PCM_S16LE }, /* 0001GL00.MXF.A1.mxf_opatom.mxf */
- { { 0x06,0x0e,0x2b,0x34,0x04,0x01,0x01,0x03,0x04,0x02,0x02,0x02,0x03,0x03,0x01,0x00 }, 14, AV_CODEC_ID_AAC }, /* MPEG2 AAC ADTS (legacy) */
+ { { 0x06,0x0e,0x2b,0x34,0x04,0x01,0x01,0x03,0x04,0x02,0x02,0x02,0x03,0x03,0x01,0x00 }, 14, AV_CODEC_ID_AAC }, /* MPEG-2 AAC ADTS (legacy) */
{ { 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00 }, 0, AV_CODEC_ID_NONE },
};
diff --git a/libavformat/mxfenc.c b/libavformat/mxfenc.c
index c5d2de0a4d..1431fc65e8 100644
--- a/libavformat/mxfenc.c
+++ b/libavformat/mxfenc.c
@@ -1127,7 +1127,7 @@ static void mxf_write_index_table_segment(AVFormatContext *s)
for (i = 0; i < mxf->edit_units_count; i++) {
int temporal_offset = 0;
- if (!(mxf->index_entries[i].flags & 0x33)) { // I frame
+ if (!(mxf->index_entries[i].flags & 0x33)) { // I-frame
mxf->last_key_index = key_index;
key_index = i;
}
@@ -1154,7 +1154,7 @@ static void mxf_write_index_table_segment(AVFormatContext *s)
mxf->last_key_index = key_index;
}
- if (!(mxf->index_entries[i].flags & 0x33) && // I frame
+ if (!(mxf->index_entries[i].flags & 0x33) && // I-frame
mxf->index_entries[i].flags & 0x40 && !temporal_offset)
mxf->index_entries[i].flags |= 0x80; // random access
avio_w8(pb, mxf->index_entries[i].flags);
@@ -1365,10 +1365,10 @@ static int mxf_parse_mpeg2_frame(AVFormatContext *s, AVStream *st,
} else if (c == 0x100) { // pic
int pict_type = (pkt->data[i+2]>>3) & 0x07;
e->temporal_ref = (pkt->data[i+1]<<2) | (pkt->data[i+2]>>6);
- if (pict_type == 2) { // P frame
+ if (pict_type == 2) { // P-frame
e->flags |= 0x22;
- sc->closed_gop = 0; // reset closed gop, don't matter anymore
- } else if (pict_type == 3) { // B frame
+ sc->closed_gop = 0; // reset closed GOP, don't matter anymore
+ } else if (pict_type == 3) { // B-frame
if (sc->closed_gop)
e->flags |= 0x13; // only backward prediction
else
@@ -1714,7 +1714,7 @@ static int mxf_write_packet(AVFormatContext *s, AVPacket *pkt)
if (st->index == 0) {
if (!mxf->edit_unit_byte_count &&
(!mxf->edit_units_count || mxf->edit_units_count > EDIT_UNITS_PER_BODY) &&
- !(ie.flags & 0x33)) { // I frame, Gop start
+ !(ie.flags & 0x33)) { // I-frame, GOP start
mxf_write_klv_fill(s);
if ((err = mxf_write_partition(s, 1, 2, body_partition_key, 0)) < 0)
return err;
diff --git a/libavformat/nsvdec.c b/libavformat/nsvdec.c
index 601357b793..1777a8b11c 100644
--- a/libavformat/nsvdec.c
+++ b/libavformat/nsvdec.c
@@ -56,14 +56,14 @@
* (that is the offset of the data table after the header).
* After checking all samples from (S1) all confirms this.
*
- * Then, about NSVf[12-15], faster.nsf has 179700. When veiwing it in VLC,
+ * Then, about NSVf[12-15], faster.nsf has 179700. When viewing it in VLC,
* I noticed there was about 1 NVSs chunk/s, so I ran
* strings faster.nsv | grep NSVs | wc -l
* which gave me 180. That leads me to think that NSVf[12-15] might be the
* file length in milliseconds.
* Let's try that:
* for f in *.nsv; do HTIME="$(od -t x4 "$f" | head -1 | sed 's/.* //')"; echo "'$f' $((0x$HTIME))s = $((0x$HTIME/1000/60)):$((0x$HTIME/1000%60))"; done
- * except for nstrailer (which doesn't have an NSVf header), it repports correct time.
+ * except for nsvtrailer (which doesn't have an NSVf header), it reports correct time.
*
* nsvtrailer.nsv (S1) does not have any NSVf header, only NSVs chunks,
* so the header seems to not be mandatory. (for streaming).
@@ -579,7 +579,7 @@ null_chunk_retry:
((auxtag >> 24) & 0x0ff),
auxsize);
avio_skip(pb, auxsize);
- vsize -= auxsize + sizeof(uint16_t) + sizeof(uint32_t); /* that's becoming braindead */
+ vsize -= auxsize + sizeof(uint16_t) + sizeof(uint32_t); /* that's becoming brain-dead */
}
if (pb->eof_reached)
@@ -681,7 +681,7 @@ static int nsv_read_packet(AVFormatContext *s, AVPacket *pkt)
}
}
- /* this restaurant is not approvisionned :^] */
+ /* this restaurant is not provisioned :^] */
return -1;
}
diff --git a/libavformat/oggparsedirac.c b/libavformat/oggparsedirac.c
index a53197e3a3..b0a3796168 100644
--- a/libavformat/oggparsedirac.c
+++ b/libavformat/oggparsedirac.c
@@ -52,7 +52,7 @@ static int dirac_header(AVFormatContext *s, int idx)
st->codecpar->profile = dsh->profile;
st->codecpar->level = dsh->level;
- // dirac in ogg always stores timestamps as though the video were interlaced
+ // Dirac in Ogg always stores timestamps as though the video were interlaced
avpriv_set_pts_info(st, 64, dsh->framerate.den, 2 * dsh->framerate.num);
av_freep(&dsh);
@@ -60,7 +60,7 @@ static int dirac_header(AVFormatContext *s, int idx)
return 1;
}
-// various undocument things: granule is signed (only for dirac!)
+// various undocumented things: granule is signed (only for Dirac!)
static uint64_t dirac_gptopts(AVFormatContext *s, int idx, uint64_t granule,
int64_t *dts_out)
{
diff --git a/libavformat/psxstr.c b/libavformat/psxstr.c
index 8b6ecc88b4..6897f26790 100644
--- a/libavformat/psxstr.c
+++ b/libavformat/psxstr.c
@@ -1,6 +1,6 @@
/*
* Sony Playstation (PSX) STR File Demuxer
- * Copyright (c) 2003 The ffmpeg Project
+ * Copyright (c) 2003 The FFmpeg project
*
* This file is part of Libav.
*
diff --git a/libavformat/rdt.c b/libavformat/rdt.c
index dac5091417..a759c7e9a2 100644
--- a/libavformat/rdt.c
+++ b/libavformat/rdt.c
@@ -44,7 +44,7 @@ struct RDTDemuxContext {
* in the AVFormatContext, and this variable points to the offset in
* that array such that the first is the first stream of this set. */
AVStream **streams;
- int n_streams; /**< streams with identifical content in this set */
+ int n_streams; /**< streams with identical content in this set */
void *dynamic_protocol_context;
DynamicPayloadPacketHandlerProc parse_packet;
uint32_t prev_timestamp;
diff --git a/libavformat/rl2.c b/libavformat/rl2.c
index 1bd9d15960..0e8d346a37 100644
--- a/libavformat/rl2.c
+++ b/libavformat/rl2.c
@@ -104,7 +104,7 @@ static av_cold int rl2_read_header(AVFormatContext *s)
if(back_size > INT_MAX/2 || frame_count > INT_MAX / sizeof(uint32_t))
return AVERROR_INVALIDDATA;
- avio_skip(pb, 2); /* encoding mentod */
+ avio_skip(pb, 2); /* encoding method */
sound_rate = avio_rl16(pb);
rate = avio_rl16(pb);
channels = avio_rl16(pb);
diff --git a/libavformat/rmenc.c b/libavformat/rmenc.c
index e4a0d60a42..8499e6384c 100644
--- a/libavformat/rmenc.c
+++ b/libavformat/rmenc.c
@@ -258,9 +258,9 @@ static int rv10_write_header(AVFormatContext *ctx,
avio_wb16(s, (int) stream->frame_rate); /* unknown meaning */
avio_wb32(s,0); /* unknown meaning */
avio_wb16(s, 8); /* unknown meaning */
- /* Seems to be the codec version: only use basic H263. The next
- versions seems to add a diffential DC coding as in
- MPEG... nothing new under the sun */
+ /* Seems to be the codec version: only use basic H.263. The next
+ versions seems to add a differential DC coding as in
+ MPEG... nothing new under the sun. */
if(stream->par->codec_id == AV_CODEC_ID_RV10)
avio_wb32(s,0x10000000);
else
@@ -397,7 +397,7 @@ static int rm_write_video(AVFormatContext *s, const uint8_t *buf, int size, int
write_packet_header(s, stream, size + 7 + (size >= 0x4000)*4, key_frame);
/* bit 7: '1' if final packet of a frame converted in several packets */
avio_w8(pb, 0x81);
- /* bit 7: '1' if I frame. bits 6..0 : sequence number in current
+ /* bit 7: '1' if I-frame. bits 6..0 : sequence number in current
frame starting from 1 */
if (key_frame) {
avio_w8(pb, 0x81);
diff --git a/libavformat/rtmphttp.c b/libavformat/rtmphttp.c
index 4806872493..5b27adeac6 100644
--- a/libavformat/rtmphttp.c
+++ b/libavformat/rtmphttp.c
@@ -129,7 +129,7 @@ static int rtmp_http_read(URLContext *h, uint8_t *buf, int size)
} else {
if (rt->nb_bytes_read == 0) {
/* Wait 50ms before retrying to read a server reply in
- * order to reduce the number of idle requets. */
+ * order to reduce the number of idle requests. */
av_usleep(50000);
}
diff --git a/libavformat/rtmpproto.c b/libavformat/rtmpproto.c
index d4f35f6b19..e7e2479f04 100644
--- a/libavformat/rtmpproto.c
+++ b/libavformat/rtmpproto.c
@@ -451,7 +451,7 @@ static int read_connect(URLContext *s, RTMPContext *rt)
tmpstr, rt->app);
ff_rtmp_packet_destroy(&pkt);
- // Send Window Acknowledgement Size (as defined in speficication)
+ // Send Window Acknowledgement Size (as defined in specification)
if ((ret = ff_rtmp_packet_create(&pkt, RTMP_NETWORK_CHANNEL,
RTMP_PT_SERVER_BW, 0, 4)) < 0)
return ret;
@@ -581,7 +581,7 @@ static int gen_release_stream(URLContext *s, RTMPContext *rt)
/**
* Generate 'FCPublish' call and send it to the server. It should make
- * the server preapare for receiving media streams.
+ * the server prepare for receiving media streams.
*/
static int gen_fcpublish_stream(URLContext *s, RTMPContext *rt)
{
@@ -1994,7 +1994,7 @@ static int send_invoke_response(URLContext *s, RTMPPacket *pkt)
* successful response, we will return set the value to number (otherwise number
* will not be changed).
*
- * @return 0 if reading the value succeeds, negative value otherwiss
+ * @return 0 if reading the value succeeds, negative value otherwise
*/
static int read_number_result(RTMPPacket *pkt, double *number)
{
@@ -2017,7 +2017,7 @@ static int read_number_result(RTMPPacket *pkt, double *number)
// Value 3/4: Null
if (ff_amf_read_null(&gbc))
return AVERROR_INVALIDDATA;
- // Value 4/4: The resonse as AMF_NUMBER
+ // Value 4/4: The response as AMF_NUMBER
if (ff_amf_read_number(&gbc, &numbuffer))
return AVERROR_INVALIDDATA;
else
@@ -2508,7 +2508,7 @@ static int rtmp_close(URLContext *h)
*/
static int inject_fake_duration_metadata(RTMPContext *rt)
{
- // We need to insert the metdata packet directly after the FLV
+ // We need to insert the metadata packet directly after the FLV
// header, i.e. we need to move all other already read data by the
// size of our fake metadata packet.
diff --git a/libavformat/rtpdec.c b/libavformat/rtpdec.c
index 3bb6b19ad9..ef51993c26 100644
--- a/libavformat/rtpdec.c
+++ b/libavformat/rtpdec.c
@@ -496,7 +496,7 @@ int ff_rtp_send_rtcp_feedback(RTPDemuxContext *s, URLContext *fd,
/**
* open a new RTP parse context for stream 'st'. 'st' can be NULL for
- * MPEG2-TS streams.
+ * MPEG-2 TS streams.
*/
RTPDemuxContext *ff_rtp_parse_open(AVFormatContext *s1, AVStream *st,
int payload_type, int queue_size)
diff --git a/libavformat/rtpdec_h263_rfc2190.c b/libavformat/rtpdec_h263_rfc2190.c
index 3a58aee22f..019eea779b 100644
--- a/libavformat/rtpdec_h263_rfc2190.c
+++ b/libavformat/rtpdec_h263_rfc2190.c
@@ -107,7 +107,7 @@ static int h263_handle_packet(AVFormatContext *ctx, PayloadContext *data,
/* Invalid src for this format, and bits that should be zero
* according to RFC 2190 aren't zero. */
av_log(ctx, AV_LOG_WARNING,
- "Interpreting H263 RTP data as RFC 2429/4629 even though "
+ "Interpreting H.263 RTP data as RFC 2429/4629 even though "
"signalled with a static payload type.\n");
data->newformat = 1;
return ff_h263_handle_packet(ctx, data, st, pkt, timestamp, buf,
diff --git a/libavformat/rtpdec_mpeg4.c b/libavformat/rtpdec_mpeg4.c
index 58bcdff786..d5fea4f59c 100644
--- a/libavformat/rtpdec_mpeg4.c
+++ b/libavformat/rtpdec_mpeg4.c
@@ -22,7 +22,7 @@
/**
* @file
- * @brief MPEG4 / RTP Code
+ * @brief MPEG-4 / RTP Code
* @author Fabrice Bellard
* @author Romain Degez
*/
@@ -136,7 +136,7 @@ static int rtp_parse_mp4_au(PayloadContext *data, const uint8_t *buf, int len)
init_get_bits(&getbitcontext, buf, data->au_headers_length_bytes * 8);
- /* XXX: Wrong if optionnal additional sections are present (cts, dts etc...) */
+ /* XXX: Wrong if optional additional sections are present (cts, dts etc...) */
au_header_size = data->sizelength + data->indexlength;
if (au_header_size <= 0 || (au_headers_length % au_header_size != 0))
return -1;
diff --git a/libavformat/rtpdec_qt.c b/libavformat/rtpdec_qt.c
index 9566c3d311..97df210916 100644
--- a/libavformat/rtpdec_qt.c
+++ b/libavformat/rtpdec_qt.c
@@ -93,7 +93,7 @@ static int qt_rtp_parse_packet(AVFormatContext *s, PayloadContext *qt,
if (pos + 12 > len)
return AVERROR_INVALIDDATA;
- skip_bits(&gb, 2); // has non-I frames:1, is sparse:1
+ skip_bits(&gb, 2); // has non-I-frames:1, is sparse:1
is_start = get_bits1(&gb);
is_finish = get_bits1(&gb);
if (!is_start || !is_finish) {
diff --git a/libavformat/rtpdec_vp8.c b/libavformat/rtpdec_vp8.c
index ae2c716397..b7f9939d05 100644
--- a/libavformat/rtpdec_vp8.c
+++ b/libavformat/rtpdec_vp8.c
@@ -46,7 +46,7 @@ struct PayloadContext {
int prev_pictureid;
int broken_frame;
/* If sequence_dirty is set, we have lost some data (critical or
- * non-critical) and decoding will have some sort of artefacts, and
+ * non-critical) and decoding will have some sort of artifacts, and
* we thus should request a new keyframe.
*/
int sequence_dirty;
diff --git a/libavformat/rtpenc.c b/libavformat/rtpenc.c
index c7733a6862..2cae839e58 100644
--- a/libavformat/rtpenc.c
+++ b/libavformat/rtpenc.c
@@ -173,7 +173,7 @@ static int rtp_write_header(AVFormatContext *s1)
case AV_CODEC_ID_H261:
if (s1->strict_std_compliance > FF_COMPLIANCE_EXPERIMENTAL) {
av_log(s, AV_LOG_ERROR,
- "Packetizing H261 is experimental and produces incorrect "
+ "Packetizing H.261 is experimental and produces incorrect "
"packetization for cases where GOBs don't fit into packets "
"(even though most receivers may handle it just fine). "
"Please set -f_strict experimental in order to enable it.\n");
@@ -189,7 +189,7 @@ static int rtp_write_header(AVFormatContext *s1)
break;
case AV_CODEC_ID_HEVC:
/* Only check for the standardized hvcC version of extradata, keeping
- * things simple and similar to the avcC/H264 case above, instead
+ * things simple and similar to the avcC/H.264 case above, instead
* of trying to handle the pre-standardization versions (as in
* libavcodec/hevc.c). */
if (st->codecpar->extradata_size > 21 && st->codecpar->extradata[0] == 1) {
diff --git a/libavformat/rtpenc.h b/libavformat/rtpenc.h
index c6ac8da43d..c4b27f05cf 100644
--- a/libavformat/rtpenc.h
+++ b/libavformat/rtpenc.h
@@ -76,7 +76,7 @@ typedef struct RTPMuxContext RTPMuxContext;
{ "latm", "Use MP4A-LATM packetization instead of MPEG4-GENERIC for AAC", 0, AV_OPT_TYPE_CONST, {.i64 = FF_RTP_FLAG_MP4A_LATM}, INT_MIN, INT_MAX, AV_OPT_FLAG_ENCODING_PARAM, "rtpflags" }, \
{ "rfc2190", "Use RFC 2190 packetization instead of RFC 4629 for H.263", 0, AV_OPT_TYPE_CONST, {.i64 = FF_RTP_FLAG_RFC2190}, INT_MIN, INT_MAX, AV_OPT_FLAG_ENCODING_PARAM, "rtpflags" }, \
{ "skip_rtcp", "Don't send RTCP sender reports", 0, AV_OPT_TYPE_CONST, {.i64 = FF_RTP_FLAG_SKIP_RTCP}, INT_MIN, INT_MAX, AV_OPT_FLAG_ENCODING_PARAM, "rtpflags" }, \
- { "h264_mode0", "Use mode 0 for H264 in RTP", 0, AV_OPT_TYPE_CONST, {.i64 = FF_RTP_FLAG_H264_MODE0}, INT_MIN, INT_MAX, AV_OPT_FLAG_ENCODING_PARAM, "rtpflags" }, \
+ { "h264_mode0", "Use mode 0 for H.264 in RTP", 0, AV_OPT_TYPE_CONST, {.i64 = FF_RTP_FLAG_H264_MODE0}, INT_MIN, INT_MAX, AV_OPT_FLAG_ENCODING_PARAM, "rtpflags" }, \
{ "send_bye", "Send RTCP BYE packets when finishing", 0, AV_OPT_TYPE_CONST, {.i64 = FF_RTP_FLAG_SEND_BYE}, INT_MIN, INT_MAX, AV_OPT_FLAG_ENCODING_PARAM, "rtpflags" } \
void ff_rtp_send_data(AVFormatContext *s1, const uint8_t *buf1, int len, int m);
diff --git a/libavformat/rtpenc_h263_rfc2190.c b/libavformat/rtpenc_h263_rfc2190.c
index f714d010f4..b8d7a0ab1c 100644
--- a/libavformat/rtpenc_h263_rfc2190.c
+++ b/libavformat/rtpenc_h263_rfc2190.c
@@ -114,7 +114,7 @@ void ff_rtp_send_h263_rfc2190(AVFormatContext *s1, const uint8_t *buf, int size,
init_get_bits(&gb, buf, size*8);
if (get_bits(&gb, 22) == 0x20) { /* Picture Start Code */
info.tr = get_bits(&gb, 8);
- skip_bits(&gb, 2); /* PTYPE start, H261 disambiguation */
+ skip_bits(&gb, 2); /* PTYPE start, H.261 disambiguation */
skip_bits(&gb, 3); /* Split screen, document camera, freeze picture release */
info.src = get_bits(&gb, 3);
info.i = get_bits(&gb, 1);
@@ -165,11 +165,11 @@ void ff_rtp_send_h263_rfc2190(AVFormatContext *s1, const uint8_t *buf, int size,
mb_info_pos++;
} else {
av_log(s1, AV_LOG_ERROR,
- "Unable to split H263 packet, use -mb_info %d "
+ "Unable to split H.263 packet, use -mb_info %d "
"or lower.\n", s->max_payload_size - 8);
}
} else {
- av_log(s1, AV_LOG_ERROR, "Unable to split H263 packet, "
+ av_log(s1, AV_LOG_ERROR, "Unable to split H.263 packet, "
"use -mb_info %d or -ps 1.\n",
s->max_payload_size - 8);
}
diff --git a/libavformat/rtpenc_jpeg.c b/libavformat/rtpenc_jpeg.c
index 00ff9744b1..9f22a09cf8 100644
--- a/libavformat/rtpenc_jpeg.c
+++ b/libavformat/rtpenc_jpeg.c
@@ -57,7 +57,7 @@ void ff_rtp_send_jpeg(AVFormatContext *s1, const uint8_t *buf, int size)
return;
}
- /* preparse the header for getting some infos */
+ /* preparse the header for getting some info */
for (i = 0; i < size; i++) {
if (buf[i] != 0xff)
continue;
diff --git a/libavformat/rtpenc_xiph.c b/libavformat/rtpenc_xiph.c
index 5b171c36a2..f6ab77f55e 100644
--- a/libavformat/rtpenc_xiph.c
+++ b/libavformat/rtpenc_xiph.c
@@ -67,7 +67,7 @@ void ff_rtp_send_xiph(AVFormatContext *s1, const uint8_t *buff, int size)
// 0 - whole frame (possibly multiple frames)
// 1 - first fragment
// 2 - fragment continuation
- // 3 - last fragmement
+ // 3 - last fragment
frag = size <= max_pkt_size ? 0 : 1;
if (!frag && !xdt) { // do we have a whole frame of raw data?
diff --git a/libavformat/sdp.c b/libavformat/sdp.c
index b513ccadc7..be6c95dc23 100644
--- a/libavformat/sdp.c
+++ b/libavformat/sdp.c
@@ -261,7 +261,7 @@ static char *extradata2psets_hevc(AVCodecParameters *par)
goto err;
nalu_type = extradata[pos] & 0x3f;
// Not including libavcodec/hevc.h to avoid confusion between
- // NAL_* with the same name for both H264 and HEVC.
+ // NAL_* with the same name for both H.264 and HEVC.
if (nalu_type == 32) // VPS
ps_pos[0] = pos;
else if (nalu_type == 33) // SPS
diff --git a/libavformat/segafilm.c b/libavformat/segafilm.c
index f74c3c0fad..16500b4349 100644
--- a/libavformat/segafilm.c
+++ b/libavformat/segafilm.c
@@ -1,6 +1,6 @@
/*
* Sega FILM Format (CPK) Demuxer
- * Copyright (c) 2003 The ffmpeg Project
+ * Copyright (c) 2003 The FFmpeg project
*
* This file is part of Libav.
*
diff --git a/libavformat/sierravmd.c b/libavformat/sierravmd.c
index 36b98f5032..604ab6b5a4 100644
--- a/libavformat/sierravmd.c
+++ b/libavformat/sierravmd.c
@@ -1,6 +1,6 @@
/*
* Sierra VMD Format Demuxer
- * Copyright (c) 2004 The ffmpeg Project
+ * Copyright (c) 2004 The FFmpeg project
*
* This file is part of Libav.
*
diff --git a/libavformat/spdif.h b/libavformat/spdif.h
index f5b15ebbb1..5ebfd91b1b 100644
--- a/libavformat/spdif.h
+++ b/libavformat/spdif.h
@@ -53,8 +53,8 @@ enum IEC61937DataType {
static const uint16_t spdif_mpeg_pkt_offset[2][3] = {
//LAYER1 LAYER2 LAYER3
- { 3072, 9216, 4608 }, // MPEG2 LSF
- { 1536, 4608, 4608 }, // MPEG1
+ { 3072, 9216, 4608 }, // MPEG-2 LSF
+ { 1536, 4608, 4608 }, // MPEG-1
};
void ff_spdif_bswap_buf16(uint16_t *dst, const uint16_t *src, int w);
diff --git a/libavformat/spdifenc.c b/libavformat/spdifenc.c
index 0e1f1d4c47..368da03fc6 100644
--- a/libavformat/spdifenc.c
+++ b/libavformat/spdifenc.c
@@ -32,7 +32,7 @@
/*
* Terminology used in specification:
* data-burst - IEC61937 frame, contains header and encapsuled frame
- * burst-preambule - IEC61937 frame header, contains 16-bits words named Pa, Pb, Pc and Pd
+ * burst-preamble - IEC61937 frame header, contains 16-bit words named Pa, Pb, Pc and Pd
* burst-payload - encapsuled frame
* Pa, Pb - syncword - 0xF872, 0x4E1F
* Pc - burst-info, contains data-type (bits 0-6), error flag (bit 7), data-type-dependent info (bits 8-12)
@@ -147,7 +147,7 @@ static int spdif_header_eac3(AVFormatContext *s, AVPacket *pkt)
* DTS type IV (DTS-HD) can be transmitted with various frame repetition
* periods; longer repetition periods allow for longer packets and therefore
* higher bitrate. Longer repetition periods mean that the constant bitrate of
- * the outputted IEC 61937 stream is higher.
+ * the output IEC 61937 stream is higher.
* The repetition period is measured in IEC 60958 frames (4 bytes).
*/
static int spdif_dts4_subtype(int period)
@@ -319,8 +319,8 @@ static int spdif_header_dts(AVFormatContext *s, AVPacket *pkt)
static const enum IEC61937DataType mpeg_data_type[2][3] = {
// LAYER1 LAYER2 LAYER3
- { IEC61937_MPEG2_LAYER1_LSF, IEC61937_MPEG2_LAYER2_LSF, IEC61937_MPEG2_LAYER3_LSF },//MPEG2 LSF
- { IEC61937_MPEG1_LAYER1, IEC61937_MPEG1_LAYER23, IEC61937_MPEG1_LAYER23 }, //MPEG1
+ { IEC61937_MPEG2_LAYER1_LSF, IEC61937_MPEG2_LAYER2_LSF, IEC61937_MPEG2_LAYER3_LSF }, // MPEG-2 LSF
+ { IEC61937_MPEG1_LAYER1, IEC61937_MPEG1_LAYER23, IEC61937_MPEG1_LAYER23 }, // MPEG-1
};
static int spdif_header_mpeg(AVFormatContext *s, AVPacket *pkt)
diff --git a/libavformat/url.h b/libavformat/url.h
index 5cbfd1a942..5853ffee7a 100644
--- a/libavformat/url.h
+++ b/libavformat/url.h
@@ -234,7 +234,7 @@ int ffurl_get_multi_file_handle(URLContext *h, int **handles, int *numhandles);
int ffurl_shutdown(URLContext *h, int flags);
/**
- * Check if the user has requested to interrup a blocking function
+ * Check if the user has requested to interrupt a blocking function
* associated with cb.
*/
int ff_check_interrupt(AVIOInterruptCB *cb);
diff --git a/libavformat/wc3movie.c b/libavformat/wc3movie.c
index c74b4404f9..2d47ad44b3 100644
--- a/libavformat/wc3movie.c
+++ b/libavformat/wc3movie.c
@@ -1,6 +1,6 @@
/*
* Wing Commander III Movie (.mve) File Demuxer
- * Copyright (c) 2003 The ffmpeg Project
+ * Copyright (c) 2003 The FFmpeg project
*
* This file is part of Libav.
*
diff --git a/libavformat/westwood_aud.c b/libavformat/westwood_aud.c
index bc8f40a954..1bfc010f56 100644
--- a/libavformat/westwood_aud.c
+++ b/libavformat/westwood_aud.c
@@ -1,6 +1,6 @@
/*
* Westwood Studios AUD Format Demuxer
- * Copyright (c) 2003 The ffmpeg Project
+ * Copyright (c) 2003 The FFmpeg project
*
* This file is part of Libav.
*
diff --git a/libavformat/westwood_vqa.c b/libavformat/westwood_vqa.c
index 9400956c92..8bd647e122 100644
--- a/libavformat/westwood_vqa.c
+++ b/libavformat/westwood_vqa.c
@@ -1,6 +1,6 @@
/*
* Westwood Studios VQA Format Demuxer
- * Copyright (c) 2003 The ffmpeg Project
+ * Copyright (c) 2003 The FFmpeg project
*
* This file is part of Libav.
*
@@ -136,7 +136,7 @@ static int wsvqa_read_header(AVFormatContext *s)
chunk_tag = AV_RB32(&scratch[0]);
chunk_size = AV_RB32(&scratch[4]);
- /* catch any unknown header tags, for curiousity */
+ /* catch any unknown header tags, for curiosity */
switch (chunk_tag) {
case CINF_TAG:
case CINH_TAG:
diff --git a/libavformat/wtv.c b/libavformat/wtv.c
index eaae2a4277..2cab4e5bd0 100644
--- a/libavformat/wtv.c
+++ b/libavformat/wtv.c
@@ -38,7 +38,7 @@
#include "asf.h"
#include "mpegts.h"
-/* Macros for formating GUIDs */
+/* Macros for formatting GUIDs */
#define PRI_PRETTY_GUID \
"%08"PRIx32"-%04"PRIx16"-%04"PRIx16"-%02x%02x%02x%02x%02x%02x%02x%02x"
#define ARG_PRETTY_GUID(g) \
@@ -328,7 +328,7 @@ typedef struct WtvContext {
AVIOContext *pb; /** timeline file */
int64_t epoch;
int64_t pts; /** pts for next data chunk */
- int64_t last_valid_pts; /** latest valid pts, used for interative seeking */
+ int64_t last_valid_pts; /** latest valid pts, used for interactive seeking */
/* maintain private seek index, as the AVIndexEntry->pos is relative to the
start of the 'timeline' file, not the file system (AVFormatContext->pb) */
diff --git a/libavformat/isom.c b/libavformat/isom.c
index 21697e8a01..226c275207 100644
--- a/libavformat/isom.c
+++ b/libavformat/isom.c
@@ -38,15 +38,15 @@ const AVCodecTag ff_mp4_obj_type[] = {
{ AV_CODEC_ID_HEVC , 0x23 },
{ AV_CODEC_ID_AAC , 0x40 },
{ AV_CODEC_ID_MP4ALS , 0x40 }, /* 14496-3 ALS */
- { AV_CODEC_ID_MPEG2VIDEO , 0x61 }, /* MPEG2 Main */
- { AV_CODEC_ID_MPEG2VIDEO , 0x60 }, /* MPEG2 Simple */
- { AV_CODEC_ID_MPEG2VIDEO , 0x62 }, /* MPEG2 SNR */
- { AV_CODEC_ID_MPEG2VIDEO , 0x63 }, /* MPEG2 Spatial */
- { AV_CODEC_ID_MPEG2VIDEO , 0x64 }, /* MPEG2 High */
- { AV_CODEC_ID_MPEG2VIDEO , 0x65 }, /* MPEG2 422 */
- { AV_CODEC_ID_AAC , 0x66 }, /* MPEG2 AAC Main */
- { AV_CODEC_ID_AAC , 0x67 }, /* MPEG2 AAC Low */
- { AV_CODEC_ID_AAC , 0x68 }, /* MPEG2 AAC SSR */
+ { AV_CODEC_ID_MPEG2VIDEO , 0x61 }, /* MPEG-2 Main */
+ { AV_CODEC_ID_MPEG2VIDEO , 0x60 }, /* MPEG-2 Simple */
+ { AV_CODEC_ID_MPEG2VIDEO , 0x62 }, /* MPEG-2 SNR */
+ { AV_CODEC_ID_MPEG2VIDEO , 0x63 }, /* MPEG-2 Spatial */
+ { AV_CODEC_ID_MPEG2VIDEO , 0x64 }, /* MPEG-2 High */
+ { AV_CODEC_ID_MPEG2VIDEO , 0x65 }, /* MPEG-2 422 */
+ { AV_CODEC_ID_AAC , 0x66 }, /* MPEG-2 AAC Main */
+ { AV_CODEC_ID_AAC , 0x67 }, /* MPEG-2 AAC Low */
+ { AV_CODEC_ID_AAC , 0x68 }, /* MPEG-2 AAC SSR */
{ AV_CODEC_ID_MP3 , 0x69 }, /* 13818-3 */
{ AV_CODEC_ID_MP2 , 0x69 }, /* 11172-3 */
{ AV_CODEC_ID_MPEG1VIDEO , 0x6A }, /* 11172-2 */
@@ -58,9 +58,9 @@ const AVCodecTag ff_mp4_obj_type[] = {
{ AV_CODEC_ID_DIRAC , 0xA4 },
{ AV_CODEC_ID_AC3 , 0xA5 },
{ AV_CODEC_ID_DTS , 0xA9 }, /* mp4ra.org */
- { AV_CODEC_ID_TSCC2 , 0xD0 }, /* non standard, camtasia uses it */
- { AV_CODEC_ID_VORBIS , 0xDD }, /* non standard, gpac uses it */
- { AV_CODEC_ID_DVD_SUBTITLE, 0xE0 }, /* non standard, see unsupported-embedded-subs-2.mp4 */
+ { AV_CODEC_ID_TSCC2 , 0xD0 }, /* nonstandard, camtasia uses it */
+ { AV_CODEC_ID_VORBIS , 0xDD }, /* nonstandard, gpac uses it */
+ { AV_CODEC_ID_DVD_SUBTITLE, 0xE0 }, /* nonstandard, see unsupported-embedded-subs-2.mp4 */
{ AV_CODEC_ID_QCELP , 0xE1 },
{ AV_CODEC_ID_MPEG4SYSTEMS, 0x01 },
{ AV_CODEC_ID_MPEG4SYSTEMS, 0x02 },
@@ -70,11 +70,11 @@ const AVCodecTag ff_mp4_obj_type[] = {
const AVCodecTag ff_codec_movvideo_tags[] = {
/* { AV_CODEC_ID_, MKTAG('I', 'V', '5', '0') }, *//* Indeo 5.0 */
- { AV_CODEC_ID_RAWVIDEO, MKTAG('r', 'a', 'w', ' ') }, /* Uncompressed RGB */
- { AV_CODEC_ID_RAWVIDEO, MKTAG('y', 'u', 'v', '2') }, /* Uncompressed YUV422 */
- { AV_CODEC_ID_RAWVIDEO, MKTAG('A', 'V', 'U', 'I') }, /* YUV with alpha-channel (AVID Uncompressed) */
- { AV_CODEC_ID_RAWVIDEO, MKTAG('2', 'v', 'u', 'y') }, /* UNCOMPRESSED 8BIT 4:2:2 */
- { AV_CODEC_ID_RAWVIDEO, MKTAG('y', 'u', 'v', 's') }, /* same as 2vuy but byte swapped */
+ { AV_CODEC_ID_RAWVIDEO, MKTAG('r', 'a', 'w', ' ') }, /* uncompressed RGB */
+ { AV_CODEC_ID_RAWVIDEO, MKTAG('y', 'u', 'v', '2') }, /* uncompressed YUV422 */
+ { AV_CODEC_ID_RAWVIDEO, MKTAG('A', 'V', 'U', 'I') }, /* YUV with alpha-channel (AVID uncompressed) */
+ { AV_CODEC_ID_RAWVIDEO, MKTAG('2', 'v', 'u', 'y') }, /* uncompressed 8-bit 4:2:2 */
+ { AV_CODEC_ID_RAWVIDEO, MKTAG('y', 'u', 'v', 's') }, /* same as 2VUY but byte-swapped */
{ AV_CODEC_ID_RAWVIDEO, MKTAG('L', '5', '5', '5') },
{ AV_CODEC_ID_RAWVIDEO, MKTAG('L', '5', '6', '5') },
@@ -93,12 +93,12 @@ const AVCodecTag ff_codec_movvideo_tags[] = {
{ AV_CODEC_ID_RAWVIDEO, MKTAG('R', '4', '2', '0') }, /* Radius DV YUV PAL */
{ AV_CODEC_ID_RAWVIDEO, MKTAG('R', '4', '1', '1') }, /* Radius DV YUV NTSC */
- { AV_CODEC_ID_R10K, MKTAG('R', '1', '0', 'k') }, /* UNCOMPRESSED 10BIT RGB */
- { AV_CODEC_ID_R10K, MKTAG('R', '1', '0', 'g') }, /* UNCOMPRESSED 10BIT RGB */
- { AV_CODEC_ID_R210, MKTAG('r', '2', '1', '0') }, /* UNCOMPRESSED 10BIT RGB */
- { AV_CODEC_ID_V210, MKTAG('v', '2', '1', '0') }, /* UNCOMPRESSED 10BIT 4:2:2 */
- { AV_CODEC_ID_V210, MKTAG('b', 'x', 'y', '2') }, /* BOXX 10BIT 4:2:2 */
- { AV_CODEC_ID_V410, MKTAG('v', '4', '1', '0') }, /* UNCOMPRESSED 10BIT 4:4:4 */
+ { AV_CODEC_ID_R10K, MKTAG('R', '1', '0', 'k') }, /* uncompressed 10-bit RGB */
+ { AV_CODEC_ID_R10K, MKTAG('R', '1', '0', 'g') }, /* uncompressed 10-bit RGB */
+ { AV_CODEC_ID_R210, MKTAG('r', '2', '1', '0') }, /* uncompressed 10-bit RGB */
+ { AV_CODEC_ID_V210, MKTAG('v', '2', '1', '0') }, /* uncompressed 10-bit 4:2:2 */
+ { AV_CODEC_ID_V210, MKTAG('b', 'x', 'y', '2') }, /* BOXX 10-bit 4:2:2 */
+ { AV_CODEC_ID_V410, MKTAG('v', '4', '1', '0') }, /* uncompressed 10-bit 4:4:4 */
{ AV_CODEC_ID_MJPEG, MKTAG('j', 'p', 'e', 'g') }, /* PhotoJPEG */
{ AV_CODEC_ID_MJPEG, MKTAG('m', 'j', 'p', 'a') }, /* Motion-JPEG (format A) */
@@ -117,8 +117,8 @@ const AVCodecTag ff_codec_movvideo_tags[] = {
{ AV_CODEC_ID_MPEG4, MKTAG('X', 'V', 'I', 'D') },
{ AV_CODEC_ID_MPEG4, MKTAG('3', 'I', 'V', '2') }, /* experimental: 3IVX files before ivx D4 4.5.1 */
- { AV_CODEC_ID_H263, MKTAG('h', '2', '6', '3') }, /* H263 */
- { AV_CODEC_ID_H263, MKTAG('s', '2', '6', '3') }, /* H263 ?? works */
+ { AV_CODEC_ID_H263, MKTAG('h', '2', '6', '3') }, /* H.263 */
+ { AV_CODEC_ID_H263, MKTAG('s', '2', '6', '3') }, /* H.263 ?? works */
{ AV_CODEC_ID_DVVIDEO, MKTAG('d', 'v', 'c', 'p') }, /* DV PAL */
{ AV_CODEC_ID_DVVIDEO, MKTAG('d', 'v', 'c', ' ') }, /* DV NTSC */
@@ -165,7 +165,7 @@ const AVCodecTag ff_codec_movvideo_tags[] = {
{ AV_CODEC_ID_H264, MKTAG('a', 'i', '1', '5') }, /* AVC-Intra 100M 1080i50 */
{ AV_CODEC_ID_H264, MKTAG('a', 'i', '1', '6') }, /* AVC-Intra 100M 1080i60 */
{ AV_CODEC_ID_H264, MKTAG('A', 'V', 'i', 'n') }, /* AVC-Intra with implicit SPS/PPS */
- { AV_CODEC_ID_H264, MKTAG('a', 'i', 'v', 'x') }, /* XAVC 4:2:2 10bit */
+ { AV_CODEC_ID_H264, MKTAG('a', 'i', 'v', 'x') }, /* XAVC 10-bit 4:2:2 */
{ AV_CODEC_ID_H264, MKTAG('r', 'v', '6', '4') }, /* X-Com Radvision */
{ AV_CODEC_ID_MPEG1VIDEO, MKTAG('m', '1', 'v', ' ') },
@@ -173,22 +173,22 @@ const AVCodecTag ff_codec_movvideo_tags[] = {
{ AV_CODEC_ID_MPEG1VIDEO, MKTAG('m', 'p', 'e', 'g') }, /* MPEG */
{ AV_CODEC_ID_MPEG1VIDEO, MKTAG('m', 'p', '1', 'v') }, /* CoreMedia CMVideoCodecType */
{ AV_CODEC_ID_MPEG2VIDEO, MKTAG('m', '2', 'v', '1') }, /* Apple MPEG-2 Camcorder */
- { AV_CODEC_ID_MPEG2VIDEO, MKTAG('h', 'd', 'v', '1') }, /* MPEG2 HDV 720p30 */
- { AV_CODEC_ID_MPEG2VIDEO, MKTAG('h', 'd', 'v', '2') }, /* MPEG2 HDV 1080i60 */
- { AV_CODEC_ID_MPEG2VIDEO, MKTAG('h', 'd', 'v', '3') }, /* MPEG2 HDV 1080i50 */
- { AV_CODEC_ID_MPEG2VIDEO, MKTAG('h', 'd', 'v', '4') }, /* MPEG2 HDV 720p24 */
- { AV_CODEC_ID_MPEG2VIDEO, MKTAG('h', 'd', 'v', '5') }, /* MPEG2 HDV 720p25 */
- { AV_CODEC_ID_MPEG2VIDEO, MKTAG('h', 'd', 'v', '6') }, /* MPEG2 HDV 1080p24 */
- { AV_CODEC_ID_MPEG2VIDEO, MKTAG('h', 'd', 'v', '7') }, /* MPEG2 HDV 1080p25 */
- { AV_CODEC_ID_MPEG2VIDEO, MKTAG('h', 'd', 'v', '8') }, /* MPEG2 HDV 1080p30 */
- { AV_CODEC_ID_MPEG2VIDEO, MKTAG('h', 'd', 'v', '9') }, /* MPEG2 HDV 720p60 JVC */
- { AV_CODEC_ID_MPEG2VIDEO, MKTAG('h', 'd', 'v', 'a') }, /* MPEG2 HDV 720p50 */
- { AV_CODEC_ID_MPEG2VIDEO, MKTAG('m', 'x', '5', 'n') }, /* MPEG2 IMX NTSC 525/60 50mb/s produced by FCP */
- { AV_CODEC_ID_MPEG2VIDEO, MKTAG('m', 'x', '5', 'p') }, /* MPEG2 IMX PAL 625/50 50mb/s produced by FCP */
- { AV_CODEC_ID_MPEG2VIDEO, MKTAG('m', 'x', '4', 'n') }, /* MPEG2 IMX NTSC 525/60 40mb/s produced by FCP */
- { AV_CODEC_ID_MPEG2VIDEO, MKTAG('m', 'x', '4', 'p') }, /* MPEG2 IMX PAL 625/50 40mb/s produced by FCP */
- { AV_CODEC_ID_MPEG2VIDEO, MKTAG('m', 'x', '3', 'n') }, /* MPEG2 IMX NTSC 525/60 30mb/s produced by FCP */
- { AV_CODEC_ID_MPEG2VIDEO, MKTAG('m', 'x', '3', 'p') }, /* MPEG2 IMX PAL 625/50 30mb/s produced by FCP */
+ { AV_CODEC_ID_MPEG2VIDEO, MKTAG('h', 'd', 'v', '1') }, /* MPEG-2 HDV 720p30 */
+ { AV_CODEC_ID_MPEG2VIDEO, MKTAG('h', 'd', 'v', '2') }, /* MPEG-2 HDV 1080i60 */
+ { AV_CODEC_ID_MPEG2VIDEO, MKTAG('h', 'd', 'v', '3') }, /* MPEG-2 HDV 1080i50 */
+ { AV_CODEC_ID_MPEG2VIDEO, MKTAG('h', 'd', 'v', '4') }, /* MPEG-2 HDV 720p24 */
+ { AV_CODEC_ID_MPEG2VIDEO, MKTAG('h', 'd', 'v', '5') }, /* MPEG-2 HDV 720p25 */
+ { AV_CODEC_ID_MPEG2VIDEO, MKTAG('h', 'd', 'v', '6') }, /* MPEG-2 HDV 1080p24 */
+ { AV_CODEC_ID_MPEG2VIDEO, MKTAG('h', 'd', 'v', '7') }, /* MPEG-2 HDV 1080p25 */
+ { AV_CODEC_ID_MPEG2VIDEO, MKTAG('h', 'd', 'v', '8') }, /* MPEG-2 HDV 1080p30 */
+ { AV_CODEC_ID_MPEG2VIDEO, MKTAG('h', 'd', 'v', '9') }, /* MPEG-2 HDV 720p60 JVC */
+ { AV_CODEC_ID_MPEG2VIDEO, MKTAG('h', 'd', 'v', 'a') }, /* MPEG-2 HDV 720p50 */
+ { AV_CODEC_ID_MPEG2VIDEO, MKTAG('m', 'x', '5', 'n') }, /* MPEG-2 IMX NTSC 525/60 50mb/s produced by FCP */
+ { AV_CODEC_ID_MPEG2VIDEO, MKTAG('m', 'x', '5', 'p') }, /* MPEG-2 IMX PAL 625/50 50mb/s produced by FCP */
+ { AV_CODEC_ID_MPEG2VIDEO, MKTAG('m', 'x', '4', 'n') }, /* MPEG-2 IMX NTSC 525/60 40mb/s produced by FCP */
+ { AV_CODEC_ID_MPEG2VIDEO, MKTAG('m', 'x', '4', 'p') }, /* MPEG-2 IMX PAL 625/50 40mb/s produced by FCP */
+ { AV_CODEC_ID_MPEG2VIDEO, MKTAG('m', 'x', '3', 'n') }, /* MPEG-2 IMX NTSC 525/60 30mb/s produced by FCP */
+ { AV_CODEC_ID_MPEG2VIDEO, MKTAG('m', 'x', '3', 'p') }, /* MPEG-2 IMX PAL 625/50 30mb/s produced by FCP */
{ AV_CODEC_ID_MPEG2VIDEO, MKTAG('x', 'd', '5', '1') }, /* XDCAM HD422 720p30 CBR */
{ AV_CODEC_ID_MPEG2VIDEO, MKTAG('x', 'd', '5', '4') }, /* XDCAM HD422 720p24 CBR */
{ AV_CODEC_ID_MPEG2VIDEO, MKTAG('x', 'd', '5', '5') }, /* XDCAM HD422 720p25 CBR */
@@ -321,7 +321,7 @@ const AVCodecTag ff_codec_movsubtitle_tags[] = {
/* map numeric codes from mdhd atom to ISO 639 */
/* cf. QTFileFormat.pdf p253, qtff.pdf p205 */
/* http://developer.apple.com/documentation/mac/Text/Text-368.html */
-/* deprecated by putting the code as 3*5bit ascii */
+/* deprecated by putting the code as 3*5 bits ASCII */
static const char mov_mdhd_language_map[][4] = {
/* 0-9 */
"eng", "fra", "ger", "ita", "dut", "sve", "spa", "dan", "por", "nor",
@@ -359,7 +359,7 @@ int ff_mov_iso639_to_lang(const char lang[4], int mp4)
/* handle undefined as such */
if (lang[0] == '\0')
lang = "und";
- /* 5bit ascii */
+ /* 5 bits ASCII */
for (i = 0; i < 3; i++) {
uint8_t c = lang[i];
c -= 0x60;
@@ -411,7 +411,7 @@ int ff_mp4_read_descr(AVFormatContext *fc, AVIOContext *pb, int *tag)
int len;
*tag = avio_r8(pb);
len = ff_mp4_read_descr_len(pb);
- av_log(fc, AV_LOG_TRACE, "MPEG4 description: tag=0x%02x len=%d\n", *tag, len);
+ av_log(fc, AV_LOG_TRACE, "MPEG-4 description: tag=0x%02x len=%d\n", *tag, len);
return len;
}
@@ -453,7 +453,7 @@ int ff_mp4_read_dec_config_descr(AVFormatContext *fc, AVStream *st, AVIOContext
av_log(fc, AV_LOG_TRACE, "esds object type id 0x%02x\n", object_type_id);
len = ff_mp4_read_descr(fc, pb, &tag);
if (tag == MP4DecSpecificDescrTag) {
- av_log(fc, AV_LOG_TRACE, "Specific MPEG4 header len=%d\n", len);
+ av_log(fc, AV_LOG_TRACE, "Specific MPEG-4 header len=%d\n", len);
if (!len || (uint64_t)len > (1<<30))
return -1;
av_free(st->codecpar->extradata);
diff --git a/libavformat/mpegts.c b/libavformat/mpegts.c
index 740cc14d43..40672aeb98 100644
--- a/libavformat/mpegts.c
+++ b/libavformat/mpegts.c
@@ -1,5 +1,5 @@
/*
- * MPEG2 transport stream (aka DVB) demuxer
+ * MPEG-2 transport stream (aka DVB) demuxer
* Copyright (c) 2002-2003 Fabrice Bellard
*
* This file is part of Libav.
@@ -36,8 +36,8 @@
#include "mpeg.h"
#include "isom.h"
/* maximum size in which we look for synchronisation if
* synchronisation is lost */
#define MAX_RESYNC_SIZE 65536
#define MAX_PES_PAYLOAD 200 * 1024
@@ -141,7 +141,7 @@ struct MpegTSContext {
};
#define MPEGTS_OPTIONS \
- { "resync_size", "Size limit for looking up a new syncronization.", offsetof(MpegTSContext, resync_size), AV_OPT_TYPE_INT, { .i64 = MAX_RESYNC_SIZE}, 0, INT_MAX, AV_OPT_FLAG_DECODING_PARAM }
+ { "resync_size", "Size limit for looking up a new synchronization.", offsetof(MpegTSContext, resync_size), AV_OPT_TYPE_INT, { .i64 = MAX_RESYNC_SIZE}, 0, INT_MAX, AV_OPT_FLAG_DECODING_PARAM }
static const AVOption options[] = {
MPEGTS_OPTIONS,
@@ -836,7 +836,7 @@ static int mpegts_push_data(MpegTSFilter *filter,
* decide */
if (pes->header[0] == 0x00 && pes->header[1] == 0x00 &&
pes->header[2] == 0x01) {
- /* it must be an mpeg2 PES stream */
+ /* it must be an MPEG-2 PES stream */
code = pes->header[3] | 0x100;
av_log(pes->stream, AV_LOG_TRACE, "pid=%x pes_code=%#x\n", pes->pid,
code);
@@ -36,8 +36,8 @@
#include "mpeg.h"
#include "isom.h"
-/* maximum size in which we look for synchronisation if
- * synchronisation is lost */
+/* maximum size in which we look for synchronization if
+ * synchronization is lost */
#define MAX_RESYNC_SIZE 65536
#define MAX_PES_PAYLOAD 200 * 1024
diff --git a/libavformat/rtpdec_h264.c b/libavformat/rtpdec_h264.c
index 43dce74c77..401d6f632c 100644
--- a/libavformat/rtpdec_h264.c
+++ b/libavformat/rtpdec_h264.c
@@ -1,5 +1,5 @@
/*
- * RTP H264 Protocol (RFC3984)
+ * RTP H.264 Protocol (RFC3984)
* Copyright (c) 2006 Ryan Martell
*
* This file is part of Libav.
@@ -285,7 +285,7 @@ static int h264_handle_packet_fu_a(AVFormatContext *ctx, AVPacket *pkt,
uint8_t fu_indicator, fu_header, start_bit, nal_type, nal;
if (len < 3) {
- av_log(ctx, AV_LOG_ERROR, "Too short data for FU-A H264 RTP packet\n");
+ av_log(ctx, AV_LOG_ERROR, "Too short data for FU-A H.264 RTP packet\n");
return AVERROR_INVALIDDATA;
}
@@ -315,14 +315,14 @@ static int h264_handle_packet(AVFormatContext *ctx, PayloadContext *data,
int result = 0;
if (!len) {
- av_log(ctx, AV_LOG_ERROR, "Empty H264 RTP packet\n");
+ av_log(ctx, AV_LOG_ERROR, "Empty H.264 RTP packet\n");
return AVERROR_INVALIDDATA;
}
nal = buf[0];
type = nal & 0x1f;
/* Simplify the case (these are all the nal types used internally by
* the h264 codec). */
if (type >= 1 && type <= 23)
type = 1;
switch (type) {
@@ -315,14 +315,14 @@ static int h264_handle_packet(AVFormatContext *ctx, PayloadContext *data,
nal = buf[0];
type = nal & 0x1f;
- /* Simplify the case (these are all the nal types used internally by
- * the h264 codec). */
+ /* Simplify the case (these are all the NAL types used internally by
+ * the H.264 codec). */
if (type >= 1 && type <= 23)
type = 1;
diff --git a/libavformat/rtpenc_h261.c b/libavformat/rtpenc_h261.c
index 514e7bf9ca..550f04f395 100644
--- a/libavformat/rtpenc_h261.c
+++ b/libavformat/rtpenc_h261.c
@@ -72,12 +72,12 @@ void ff_rtp_send_h261(AVFormatContext *ctx, const uint8_t *frame_buf, int frame_
rtp_ctx->buf[2] = 0; /* quant=0, hmvd=5 */
rtp_ctx->buf[3] = 0; /* vmvd=0 */
if (frame_size < 2 || frame_buf[0] != 0 || frame_buf[1] != 1) {
/* A full, correct fix for this would be to make the H261 encoder
* support inserting extra GOB headers (triggered by setting e.g.
* "-ps 1"), and including information about macroblock boundaries
* (such as for h263_rfc2190). */
av_log(ctx, AV_LOG_WARNING,
- "RTP/H261 packet not cut at a GOB boundary, not signaled correctly\n");
+ "RTP/H.261 packet not cut at a GOB boundary, not signaled correctly\n");
}
cur_frame_size = FFMIN(rtp_ctx->max_payload_size - RTP_H261_HEADER_SIZE, frame_size);
@@ -72,12 +72,12 @@ void ff_rtp_send_h261(AVFormatContext *ctx, const uint8_t *frame_buf, int frame_
rtp_ctx->buf[3] = 0; /* vmvd=0 */
if (frame_size < 2 || frame_buf[0] != 0 || frame_buf[1] != 1) {
- /* A full, correct fix for this would be to make the H261 encoder
+ /* A full, correct fix for this would be to make the H.261 encoder
* support inserting extra GOB headers (triggered by setting e.g.
* "-ps 1"), and including information about macroblock boundaries